# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdInput(Component):
    """An AntdInput component.
    输入框组件AntdInput

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - styles (dict; optional):
        细分控制子元素css样式.

        `styles` is a dict with keys:

        - input (dict; optional):
            控制文本框元素css样式.

        - prefix (dict; optional):
            控制前缀容器css样式.

        - suffix (dict; optional):
            控制后缀容器css样式.

        - count (dict; optional):
            控制文字计数元素css样式.

        - textarea (dict; optional):
            控制文本域元素css样式.

    - classNames (dict; optional):
        细分控制子元素css类名.

        `classNames` is a dict with keys:

        - input (string; optional):
            控制文本框元素css类名.

        - prefix (string; optional):
            控制前缀容器css类名.

        - suffix (string; optional):
            控制后缀容器css类名.

        - count (string; optional):
            控制文字计数元素css类名.

        - textarea (string; optional):
            控制文本域元素css类名.

    - name (string; optional):
        配合`AntdForm`表单批量值搜集/控制功能使用，充当当前表单项的字段名，以`id`作为缺省值.

    - enableBatchControl (boolean; default True):
        控制当前组件是否参与有效的`AntdForm`表单批量值搜集/控制功能 默认值：`True`.

    - mode (a value equal to: 'default', 'search', 'text-area', 'password'; default 'default'):
        输入框模式，可选项有`'default'`、`'search'`、`'text-area'`、`'password'`
        默认值：`'default'`.

    - autoComplete (a value equal to: 'off', 'on'; default 'on'):
        是否开启浏览器自带的自动补全功能，可选项有`'off'`、`'on'` 默认值：`'on'`.

    - disabled (boolean; default False):
        是否禁用当前组件 默认值：`False`.

    - size (a value equal to: 'small', 'middle', 'large'; default 'middle'):
        当前组件尺寸规格，可选项有`'small'`、`'middle'`、`'large'` 默认值：`'middle'`.

    - bordered (boolean; default True):
        是否显示边框，设置为`True`时等价于`variant='outlined'` 默认值：`True`.

    - variant (a value equal to: 'outlined', 'borderless', 'filled', 'underlined'; optional):
        形态变体类型，可选项有`'outlined'`、`'borderless'`、`'filled'`、`'underlined'`，其中`'outlined'`等价于`bordered=True`，但优先级更高.

    - placeholder (string; optional):
        输入框占位文字内容.

    - value (string; optional):
        监听或设置已输入值.

    - defaultValue (string; optional):
        初始化已输入值.

    - passwordUseMd5 (boolean; default False):
        针对`'password'`模式，是否启用md5加密功能 默认值：`False`.

    - md5Value (string; optional):
        当`passwordUseMd5=True`时，监听已输入值md5编码结果.

    - debounceValue (string; optional):
        监听防抖版本的已输入值.

    - debounceWait (number; default 0):
        防抖延时时长，单位：毫秒 默认值：`0`.

    - addonBefore (a list of or a singular dash component, string or number; optional):
        组件型，前置标签内容.

    - addonAfter (a list of or a singular dash component, string or number; optional):
        组件型，后置标签内容.

    - prefix (a list of or a singular dash component, string or number; optional):
        组件型，前缀内嵌内容.

    - suffix (a list of or a singular dash component, string or number; optional):
        组件型，后缀内嵌内容.

    - maxLength (number; optional):
        限制输入框最大可输入字符数量.

    - showCount (boolean; default False):
        是否显示已输入字符计数 默认值：`False`.

    - countFormat (string; optional):
        正则表达式，用于配合字符计数相关功能，自定义计数规则.

    - autoSize (dict; default False):
        针对`'text-area'`模式，配置输入框高度自适应相关功能 默认值：`False`.

        `autoSize` is a boolean | dict with keys:

        - minRows (number; optional):
            输入框最小行数.

        - maxRows (number; optional):
            输入框最大行数.

    - nSubmit (number; default 0):
        监听输入框聚焦状态下，键盘enter键累计点按次数 默认值：`0`.

    - nClicksSearch (number; default 0):
        针对`'search'`模式，监听搜索按钮累计点击次数 默认值：`0`.

    - status (a value equal to: 'error', 'warning'; optional):
        控制校验状态，可选项有`'error'`、`'warning'`.

    - allowClear (boolean; default False):
        是否允许一键清空已输入值 默认值：`False`.

    - autoFocus (boolean; default False):
        是否自动获取焦点 默认值：`False`.

    - focusing (boolean; optional):
        监听输入框是否聚焦.

    - readOnly (boolean; optional):
        是否渲染为只读状态 默认值：`False`.

    - emptyAsNone (boolean; default False):
        当输入框已输入值为空时，是否强制更新`value`为空值，从而统一空字符串与空值混合的情况 默认值：`False`.

    - batchPropsNames (list of strings; optional):
        需要纳入[批量属性监听](/batch-props-values)的若干属性名.

    - batchPropsValues (dict; optional):
        监听`batchPropsNames`中指定的若干属性值.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配.

    - persistence (boolean | string | number; optional):
        是否开启[属性持久化](/prop-persistence).

    - persisted_props (list of a value equal to: 'value', 'md5Value's; optional):
        开启属性持久化功能的若干属性名，可选项有`'value'`、`'md5Value'` 默认值：`['value',
        'md5Value']`.

    - persistence_type (a value equal to: 'local', 'session', 'memory'; optional):
        属性持久化存储类型，可选项有`'local'`（本地持久化），`'session'`（会话持久化），`'memory'`（内存持久化）
        默认值：`'local'`."""

    _children_props: typing.List[str] = ['addonBefore', 'addonAfter', 'prefix', 'suffix']
    _base_nodes = ['addonBefore', 'addonAfter', 'prefix', 'suffix', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdInput'
    Styles = TypedDict(
        'Styles',
        {
            'input': NotRequired[dict],
            'prefix': NotRequired[dict],
            'suffix': NotRequired[dict],
            'count': NotRequired[dict],
            'textarea': NotRequired[dict],
        },
    )

    ClassNames = TypedDict(
        'ClassNames',
        {
            'input': NotRequired[str],
            'prefix': NotRequired[str],
            'suffix': NotRequired[str],
            'count': NotRequired[str],
            'textarea': NotRequired[str],
        },
    )

    AutoSize = TypedDict(
        'AutoSize', {'minRows': NotRequired[NumberType], 'maxRows': NotRequired[NumberType]}
    )

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        styles: typing.Optional['Styles'] = None,
        classNames: typing.Optional['ClassNames'] = None,
        name: typing.Optional[str] = None,
        enableBatchControl: typing.Optional[bool] = None,
        mode: typing.Optional[Literal['default', 'search', 'text-area', 'password']] = None,
        autoComplete: typing.Optional[Literal['off', 'on']] = None,
        disabled: typing.Optional[bool] = None,
        size: typing.Optional[Literal['small', 'middle', 'large']] = None,
        bordered: typing.Optional[bool] = None,
        variant: typing.Optional[Literal['outlined', 'borderless', 'filled', 'underlined']] = None,
        placeholder: typing.Optional[str] = None,
        value: typing.Optional[str] = None,
        defaultValue: typing.Optional[str] = None,
        passwordUseMd5: typing.Optional[bool] = None,
        md5Value: typing.Optional[str] = None,
        debounceValue: typing.Optional[str] = None,
        debounceWait: typing.Optional[NumberType] = None,
        addonBefore: typing.Optional[ComponentType] = None,
        addonAfter: typing.Optional[ComponentType] = None,
        prefix: typing.Optional[ComponentType] = None,
        suffix: typing.Optional[ComponentType] = None,
        maxLength: typing.Optional[NumberType] = None,
        showCount: typing.Optional[bool] = None,
        countFormat: typing.Optional[str] = None,
        autoSize: typing.Optional[typing.Union[bool, 'AutoSize']] = None,
        nSubmit: typing.Optional[NumberType] = None,
        nClicksSearch: typing.Optional[NumberType] = None,
        status: typing.Optional[Literal['error', 'warning']] = None,
        allowClear: typing.Optional[bool] = None,
        autoFocus: typing.Optional[bool] = None,
        focusing: typing.Optional[bool] = None,
        readOnly: typing.Optional[bool] = None,
        emptyAsNone: typing.Optional[bool] = None,
        batchPropsNames: typing.Optional[typing.Sequence[str]] = None,
        batchPropsValues: typing.Optional[dict] = None,
        persistence: typing.Optional[typing.Union[bool, str, NumberType]] = None,
        persisted_props: typing.Optional[typing.Sequence[Literal['value', 'md5Value']]] = None,
        persistence_type: typing.Optional[Literal['local', 'session', 'memory']] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'styles',
            'classNames',
            'name',
            'enableBatchControl',
            'mode',
            'autoComplete',
            'disabled',
            'size',
            'bordered',
            'variant',
            'placeholder',
            'value',
            'defaultValue',
            'passwordUseMd5',
            'md5Value',
            'debounceValue',
            'debounceWait',
            'addonBefore',
            'addonAfter',
            'prefix',
            'suffix',
            'maxLength',
            'showCount',
            'countFormat',
            'autoSize',
            'nSubmit',
            'nClicksSearch',
            'status',
            'allowClear',
            'autoFocus',
            'focusing',
            'readOnly',
            'emptyAsNone',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'styles',
            'classNames',
            'name',
            'enableBatchControl',
            'mode',
            'autoComplete',
            'disabled',
            'size',
            'bordered',
            'variant',
            'placeholder',
            'value',
            'defaultValue',
            'passwordUseMd5',
            'md5Value',
            'debounceValue',
            'debounceWait',
            'addonBefore',
            'addonAfter',
            'prefix',
            'suffix',
            'maxLength',
            'showCount',
            'countFormat',
            'autoSize',
            'nSubmit',
            'nClicksSearch',
            'status',
            'allowClear',
            'autoFocus',
            'focusing',
            'readOnly',
            'emptyAsNone',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdInput, self).__init__(**args)


setattr(AntdInput, '__init__', _explicitize_args(AntdInput.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdFloatButtonGroup(Component):
    """An AntdFloatButtonGroup component.
    悬浮按钮组组件AntdFloatButtonGroup

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - children (a list of or a singular dash component, string or number; optional):
        当前悬浮按钮组内悬浮按钮.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - icon (a list of or a singular dash component, string or number; optional):
        图标元素.

    - description (a list of or a singular dash component, string or number; optional):
        描述内容.

    - tooltip (dict; optional):
        气泡卡片内容.

        `tooltip` is a a list of or a singular dash component, string or
        number | dict with keys:

        - title (a list of or a singular dash component, string or number; optional):
            气泡卡片内容.

        - color (string; optional):
            气泡卡片背景色.

        - placement (a value equal to: 'top', 'left', 'right', 'bottom', 'topLeft', 'topRight', 'bottomLeft', 'bottomRight', 'leftTop', 'leftBottom', 'rightTop', 'rightBottom'; optional):
            气泡卡片展开方向，可选项有`'top'`、`'left'`、`'right'`、`'bottom'`、`'topLeft'`、`'topRight'`、`'bottomLeft'`、`'bottomRight'`、`'leftTop'`、`'leftBottom'`、`'rightTop'`、`'rightBottom'`.

    - type (a value equal to: 'default', 'primary'; default 'default'):
        按钮类型，可选项有`'default'`、`'primary'` 默认值：`'default'`.

    - shape (a value equal to: 'circle', 'square'; default 'circle'):
        内部各悬浮按钮形状，可选项有`'circle'`、`'square'` 默认值：`'circle'`.

    - trigger (a value equal to: 'click', 'hover'; optional):
        菜单展开模式触发方式，可选项有`'click'`、`'hover'`.

    - placement (a value equal to: 'top', 'right', 'bottom', 'left'; optional):
        菜单展开方向，可选项有`'top'`、`'right'`、`'bottom'`、`'left'`.

    - open (boolean; optional):
        设置或监听当前悬浮按钮组展开状态.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = ['icon', 'description', 'tooltip', 'tooltip.title']
    _base_nodes = ['icon', 'description', 'tooltip', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdFloatButtonGroup'
    Tooltip = TypedDict(
        'Tooltip',
        {
            'title': NotRequired[ComponentType],
            'color': NotRequired[str],
            'placement': NotRequired[
                Literal[
                    'top',
                    'left',
                    'right',
                    'bottom',
                    'topLeft',
                    'topRight',
                    'bottomLeft',
                    'bottomRight',
                    'leftTop',
                    'leftBottom',
                    'rightTop',
                    'rightBottom',
                ]
            ],
        },
    )

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        icon: typing.Optional[ComponentType] = None,
        description: typing.Optional[ComponentType] = None,
        tooltip: typing.Optional[typing.Union[ComponentType, 'Tooltip']] = None,
        type: typing.Optional[Literal['default', 'primary']] = None,
        shape: typing.Optional[Literal['circle', 'square']] = None,
        trigger: typing.Optional[Literal['click', 'hover']] = None,
        placement: typing.Optional[Literal['top', 'right', 'bottom', 'left']] = None,
        open: typing.Optional[bool] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'icon',
            'description',
            'tooltip',
            'type',
            'shape',
            'trigger',
            'placement',
            'open',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'icon',
            'description',
            'tooltip',
            'type',
            'shape',
            'trigger',
            'placement',
            'open',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdFloatButtonGroup, self).__init__(children=children, **args)


setattr(AntdFloatButtonGroup, '__init__', _explicitize_args(AntdFloatButtonGroup.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdBadge(Component):
    """An AntdBadge component.
    徽标组件AntdBadge

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，定义徽标添加目标元素.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - styles (dict; optional):
        细分控制子元素css样式.

        `styles` is a dict with keys:

        - root (dict; optional):
            控制根元素css样式.

        - indicator (dict; optional):
            控制徽标元素css样式.

    - classNames (dict; optional):
        细分控制子元素css类.

        `classNames` is a dict with keys:

        - root (string; optional):
            控制根元素css类.

        - indicator (string; optional):
            控制徽标元素css类.

    - color (string; optional):
        徽标颜色.

    - count (number; optional):
        徽标显示的数字.

    - dot (boolean; default False):
        是否用圆点代替数字显示 默认值：`False`.

    - showZero (boolean; default False):
        当`count=0`时，是否强制显示数字 默认值：`False`.

    - overflowCount (number; default 99):
        数字显示上限，超出会以显示`+`后缀 默认值：`99`.

    - offset (list of numbers; optional):
        徽标在水平、竖直方向上的像素偏移，格式为`[水平偏移, 竖直偏移]`.

    - status (a value equal to: 'success', 'processing', 'default', 'error', 'warning'; optional):
        徽标状态，可选项有`'success'`、`'processing'`、`'default'`、`'error'`、`'warning'`.

    - text (string; optional):
        参数`status`有效时，设置徽标文本内容.

    - title (string; optional):
        徽标鼠标悬停显示文字内容.

    - size (a value equal to: 'default', 'small'; default 'default'):
        徽标尺寸规格，可选项有`'default'`、`'small'`.

    - nClicks (number; default 0):
        监听徽标累计被点击次数 默认值：`0`.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdBadge'
    Styles = TypedDict('Styles', {'root': NotRequired[dict], 'indicator': NotRequired[dict]})

    ClassNames = TypedDict('ClassNames', {'root': NotRequired[str], 'indicator': NotRequired[str]})

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        styles: typing.Optional['Styles'] = None,
        classNames: typing.Optional['ClassNames'] = None,
        color: typing.Optional[str] = None,
        count: typing.Optional[NumberType] = None,
        dot: typing.Optional[bool] = None,
        showZero: typing.Optional[bool] = None,
        overflowCount: typing.Optional[NumberType] = None,
        offset: typing.Optional[typing.Sequence[NumberType]] = None,
        status: typing.Optional[
            Literal['success', 'processing', 'default', 'error', 'warning']
        ] = None,
        text: typing.Optional[str] = None,
        title: typing.Optional[str] = None,
        size: typing.Optional[Literal['default', 'small']] = None,
        nClicks: typing.Optional[NumberType] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'styles',
            'classNames',
            'color',
            'count',
            'dot',
            'showZero',
            'overflowCount',
            'offset',
            'status',
            'text',
            'title',
            'size',
            'nClicks',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'styles',
            'classNames',
            'color',
            'count',
            'dot',
            'showZero',
            'overflowCount',
            'offset',
            'status',
            'text',
            'title',
            'size',
            'nClicks',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdBadge, self).__init__(children=children, **args)


setattr(AntdBadge, '__init__', _explicitize_args(AntdBadge.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdPopconfirm(Component):
    """An AntdPopconfirm component.
    气泡确认框组件AntdPopconfirm

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，气泡确认框挂载元素.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - styles (dict; optional):
        细分控制子元素css样式.

        `styles` is a dict with keys:

        - root (dict; optional):
            根元素（包含箭头、内容元素）css样式.

        - body (dict; optional):
            内容元素css样式.

    - classNames (dict; optional):
        细分控制子元素css类名.

        `classNames` is a dict with keys:

        - root (string; optional):
            根元素（包含箭头、内容元素）css类名.

        - body (string; optional):
            内容元素css类名.

    - locale (a value equal to: 'zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr'; default 'zh-cn'):
        组件文案语种，可选项有`'zh-cn'`（简体中文）、`'en-us'`（英语）、`'de-de'`（德语）、`'fr-fr'`（法语）、`'ru-ru'`（俄语）
        默认值：`'zh-cn'`.

    - icon (a list of or a singular dash component, string or number; optional):
        组件型，提示图标.

    - title (a list of or a singular dash component, string or number; optional):
        组件型，标题内容.

    - description (a list of or a singular dash component, string or number; optional):
        组件型，描述内容.

    - disabled (boolean; default False):
        是否禁用当前组件 默认值：`False`.

    - placement (a value equal to: 'top', 'left', 'right', 'bottom', 'topLeft', 'topRight', 'bottomLeft', 'bottomRight', 'leftTop', 'leftBottom', 'rightTop', 'rightBottom'; default 'top'):
        气泡确认框弹出位置，可选项有`'top'`、`'left'`、`'right'`、`'bottom'`、`'topLeft'`、`'topRight'`、`'bottomLeft'`、`'bottomRight'`、`'leftTop'`、`'leftBottom'`、`'rightTop'`、`'rightBottom'`
        默认值：`'top'`.

    - mouseEnterDelay (number; default 0.1):
        从鼠标移入挂载元素，到气泡确认框显示的延时，单位：秒 默认值：`0.1`.

    - mouseLeaveDelay (number; default 0.1):
        从鼠标移出挂载元素，到气泡确认框消失的延时，单位：秒 默认值：`0.1`.

    - okText (a list of or a singular dash component, string or number; optional):
        组件型，确认按钮内容.

    - okButtonProps (dict; optional):
        配置确认按钮相关参数.

        `okButtonProps` is a dict with keys:

        - size (a value equal to: 'small', 'middle', 'large'; optional):
            按钮尺寸规格，可选项有`'small'`、`'middle'`、`'large'` 默认值：`'middle'`.

        - type (a value equal to: 'primary', 'ghost', 'dashed', 'link', 'text', 'default'; optional):
            按钮类型，可选项有`'default'`、`'primary'`、`'ghost'`、`'dashed'`、`'link'`、`'text'`
            默认值：`'default'`.

        - danger (boolean; optional):
            按钮是否呈现危险样式 默认值：`False`.

        - disabled (boolean; optional):
            按钮是否呈现禁用状态 默认值：`False`.

        - shape (a value equal to: 'circle', 'round'; optional):
            按钮形状，可选项有`'default'`、`'circle'`、`'round'` 默认值：`'default'`.

        - style (dict; optional):
            按钮css样式.

        - className (string; optional):
            按钮css类名.

    - cancelText (a list of or a singular dash component, string or number; optional):
        组件型，取消按钮内容.

    - cancelButtonProps (dict; optional):
        配置取消按钮相关参数.

        `cancelButtonProps` is a dict with keys:

        - size (a value equal to: 'small', 'middle', 'large'; optional):
            按钮尺寸规格，可选项有`'small'`、`'middle'`、`'large'` 默认值：`'middle'`.

        - type (a value equal to: 'primary', 'ghost', 'dashed', 'link', 'text', 'default'; optional):
            按钮类型，可选项有`'default'`、`'primary'`、`'ghost'`、`'dashed'`、`'link'`、`'text'`
            默认值：`'default'`.

        - danger (boolean; optional):
            按钮是否呈现危险样式 默认值：`False`.

        - disabled (boolean; optional):
            按钮是否呈现禁用状态 默认值：`False`.

        - shape (a value equal to: 'circle', 'round'; optional):
            按钮形状，可选项有`'default'`、`'circle'`、`'round'` 默认值：`'default'`.

        - style (dict; optional):
            按钮css样式.

        - className (string; optional):
            按钮css类名.

    - showCancel (boolean; default True):
        是否显示取消按钮 默认值：`True`.

    - confirmCounts (number; default 0):
        监听确认按钮累计点击次数 默认值：`0`.

    - cancelCounts (number; default 0):
        监听取消按钮累计点击次数 默认值：`0`.

    - trigger (a value equal to: 'hover', 'focus', 'click' | list of a value equal to: 'hover', 'focus', 'click's; default 'click'):
        气泡确认框触发行为，可选项有`'hover'`、`'focus'`、`'click'`，可多选组合 默认值：`'click'`.

    - zIndex (number; optional):
        气泡确认框z-index.

    - arrow (a value equal to: 'show', 'hide', 'center'; default 'show'):
        指示箭头显示形式，可选项有`'show'`、`'hide'`、`'center'` 默认值：`'show'`.

    - fresh (boolean; default False):
        是否保持内容更新 默认值：`False`.

    - open (boolean; default False):
        监听或设置气泡确认框的显示状态 默认值：`False`.

    - permanent (boolean; default False):
        是否保持气泡确认框显示/隐藏 默认值：`False`.

    - popupContainer (a value equal to: 'parent', 'body'; default 'body'):
        悬浮层渲染挂载父节点策略，可选项有`'parent'`、`'body'` 默认值：`'body'`.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配.

    - loading_state (dict; optional)

        `loading_state` is a dict with keys:

        - is_loading (boolean; optional):
            Determines if the component is loading or not.

        - prop_name (string; optional):
            Holds which property is loading.

        - component_name (string; optional):
            Holds the name of the component that is loading."""

    _children_props: typing.List[str] = ['icon', 'title', 'description', 'okText', 'cancelText']
    _base_nodes = ['icon', 'title', 'description', 'okText', 'cancelText', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdPopconfirm'
    Styles = TypedDict('Styles', {'root': NotRequired[dict], 'body': NotRequired[dict]})

    ClassNames = TypedDict('ClassNames', {'root': NotRequired[str], 'body': NotRequired[str]})

    OkButtonProps = TypedDict(
        'OkButtonProps',
        {
            'size': NotRequired[Literal['small', 'middle', 'large']],
            'type': NotRequired[Literal['primary', 'ghost', 'dashed', 'link', 'text', 'default']],
            'danger': NotRequired[bool],
            'disabled': NotRequired[bool],
            'shape': NotRequired[Literal['circle', 'round']],
            'style': NotRequired[dict],
            'className': NotRequired[str],
        },
    )

    CancelButtonProps = TypedDict(
        'CancelButtonProps',
        {
            'size': NotRequired[Literal['small', 'middle', 'large']],
            'type': NotRequired[Literal['primary', 'ghost', 'dashed', 'link', 'text', 'default']],
            'danger': NotRequired[bool],
            'disabled': NotRequired[bool],
            'shape': NotRequired[Literal['circle', 'round']],
            'style': NotRequired[dict],
            'className': NotRequired[str],
        },
    )

    LoadingState = TypedDict(
        'LoadingState',
        {
            'is_loading': NotRequired[bool],
            'prop_name': NotRequired[str],
            'component_name': NotRequired[str],
        },
    )

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        styles: typing.Optional['Styles'] = None,
        classNames: typing.Optional['ClassNames'] = None,
        locale: typing.Optional[Literal['zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr']] = None,
        icon: typing.Optional[ComponentType] = None,
        title: typing.Optional[ComponentType] = None,
        description: typing.Optional[ComponentType] = None,
        disabled: typing.Optional[bool] = None,
        placement: typing.Optional[
            Literal[
                'top',
                'left',
                'right',
                'bottom',
                'topLeft',
                'topRight',
                'bottomLeft',
                'bottomRight',
                'leftTop',
                'leftBottom',
                'rightTop',
                'rightBottom',
            ]
        ] = None,
        mouseEnterDelay: typing.Optional[NumberType] = None,
        mouseLeaveDelay: typing.Optional[NumberType] = None,
        okText: typing.Optional[ComponentType] = None,
        okButtonProps: typing.Optional['OkButtonProps'] = None,
        cancelText: typing.Optional[ComponentType] = None,
        cancelButtonProps: typing.Optional['CancelButtonProps'] = None,
        showCancel: typing.Optional[bool] = None,
        confirmCounts: typing.Optional[NumberType] = None,
        cancelCounts: typing.Optional[NumberType] = None,
        trigger: typing.Optional[
            typing.Union[
                Literal['hover', 'focus', 'click'],
                typing.Sequence[Literal['hover', 'focus', 'click']],
            ]
        ] = None,
        zIndex: typing.Optional[NumberType] = None,
        arrow: typing.Optional[Literal['show', 'hide', 'center']] = None,
        fresh: typing.Optional[bool] = None,
        open: typing.Optional[bool] = None,
        permanent: typing.Optional[bool] = None,
        popupContainer: typing.Optional[Literal['parent', 'body']] = None,
        loading_state: typing.Optional['LoadingState'] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'styles',
            'classNames',
            'locale',
            'icon',
            'title',
            'description',
            'disabled',
            'placement',
            'mouseEnterDelay',
            'mouseLeaveDelay',
            'okText',
            'okButtonProps',
            'cancelText',
            'cancelButtonProps',
            'showCancel',
            'confirmCounts',
            'cancelCounts',
            'trigger',
            'zIndex',
            'arrow',
            'fresh',
            'open',
            'permanent',
            'popupContainer',
            'data-*',
            'aria-*',
            'loading_state',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'styles',
            'classNames',
            'locale',
            'icon',
            'title',
            'description',
            'disabled',
            'placement',
            'mouseEnterDelay',
            'mouseLeaveDelay',
            'okText',
            'okButtonProps',
            'cancelText',
            'cancelButtonProps',
            'showCancel',
            'confirmCounts',
            'cancelCounts',
            'trigger',
            'zIndex',
            'arrow',
            'fresh',
            'open',
            'permanent',
            'popupContainer',
            'data-*',
            'aria-*',
            'loading_state',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdPopconfirm, self).__init__(children=children, **args)


setattr(AntdPopconfirm, '__init__', _explicitize_args(AntdPopconfirm.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdAnchor(Component):
    """An AntdAnchor component.
    锚点组件AntdAnchor

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - linkDict (optional):
        目录层次数据结构.

    - direction (a value equal to: 'vertical', 'horizontal'; default 'vertical'):
        导航方向，可选项有`'vertical'`、`'horizontal'`，其中`'horizontal'`方向下不支持子目录
        默认值：`'vertical'`.

    - align (a value equal to: 'left', 'right'; default 'right'):
        锚点位置，可选项有`'left'`、`'right'` 默认值：`'right'`.

    - containerId (string; optional):
        锚点目标容器id.

    - targetOffset (number; optional):
        锚点位移偏移量，默认同参数offsetTop.

    - affix (boolean; default True):
        是否开启固定模式 默认值：`True`.

    - bounds (number; default 5):
        锚点像素边距 默认值：`5`.

    - offsetTop (number; optional):
        设置距离窗口顶部触发锚定效果的指定像素偏移量.

    - replace (boolean; default False):
        设置为`True`后，浏览器后退或前进时，不会跳转到锚点地址 默认值：`False`.

    - currentAnchor (string; optional):
        强制指定当前处于高亮状态的锚点链接.

    - clickedLink (dict; optional):
        监听锚点节点点击事件.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdAnchor'

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        linkDict: typing.Optional[typing.Any] = None,
        direction: typing.Optional[Literal['vertical', 'horizontal']] = None,
        align: typing.Optional[Literal['left', 'right']] = None,
        containerId: typing.Optional[str] = None,
        targetOffset: typing.Optional[NumberType] = None,
        affix: typing.Optional[bool] = None,
        bounds: typing.Optional[NumberType] = None,
        offsetTop: typing.Optional[NumberType] = None,
        replace: typing.Optional[bool] = None,
        currentAnchor: typing.Optional[str] = None,
        clickedLink: typing.Optional[dict] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'linkDict',
            'direction',
            'align',
            'containerId',
            'targetOffset',
            'affix',
            'bounds',
            'offsetTop',
            'replace',
            'currentAnchor',
            'clickedLink',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'linkDict',
            'direction',
            'align',
            'containerId',
            'targetOffset',
            'affix',
            'bounds',
            'offsetTop',
            'replace',
            'currentAnchor',
            'clickedLink',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdAnchor, self).__init__(**args)


setattr(AntdAnchor, '__init__', _explicitize_args(AntdAnchor.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdTreeSelect(Component):
    """An AntdTreeSelect component.
    树选择组件AntdTreeSelect

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - popupClassName (string; optional):
        展开菜单css类名.

    - name (string; optional):
        配合`AntdForm`表单批量值搜集/控制功能使用，充当当前表单项的字段名，以`id`作为缺省值.

    - enableBatchControl (boolean; default True):
        控制当前组件是否参与有效的`AntdForm`表单批量值搜集/控制功能 默认值：`True`.

    - locale (a value equal to: 'zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr'; default 'zh-cn'):
        组件文案语种，可选项有`'zh-cn'`（简体中文）、`'en-us'`（英语）、`'de-de'`（德语）、`'fr-fr'`（法语）、`'ru-ru'`（俄语）
        默认值：`'zh-cn'`.

    - treeDataMode (a value equal to: 'tree', 'flat'; default 'tree'):
        对应`treeData`格式的渲染模式，可选项有`'tree'`（树形模式）、`'flat'`（扁平模式）
        默认值：`'tree'`.

    - treeData (list; required):
        定义构造树所需的数据结构，与`treeDataMode`一致.

    - treeNodeKeyToTitle (dict with strings as keys and values of type a list of or a singular dash component, string or number; optional):
        针对树结构中的指定节点，定义作为标题的组件型内容，优先级高于`treeData`中对应的`title`值.

    - disabled (boolean; default False):
        是否禁用当前组件 默认值：`False`.

    - size (a value equal to: 'small', 'middle', 'large'; default 'middle'):
        当前组件尺寸规格，可选项有`'small'`、`'middle'`、`'large'` 默认值：`'middle'`.

    - bordered (boolean; default True):
        是否显示边框，设置为`True`时等价于`variant='outlined'` 默认值：`True`.

    - variant (a value equal to: 'outlined', 'borderless', 'filled', 'underlined'; optional):
        设置形态变体类型，可选的有'outlined'、'borderless'、'filled'、`'underlined'`，其中'outlined'等价于bordered=True，优先级高于bordered.

    - placeholder (string; optional):
        输入框占位文字内容.

    - placement (a value equal to: 'bottomLeft', 'bottomRight', 'topLeft', 'topRight'; default 'bottomLeft'):
        选择菜单展开方向，可选项有`'bottomLeft'`、`'bottomRight'`、`'topLeft'`、`'topRight'`
        默认值：`'bottomLeft'`.

    - treeLine (boolean; default False):
        是否显示连接线 默认值：`False`.

    - value (string | number | list of string | numbers; optional):
        监听或设置已选值.

    - defaultValue (string | number | list of string | numbers; optional):
        初始化已选值.

    - maxCount (number; optional):
        当`multiple=True`时，可选中的最大数量
        如果`showCheckedStrategy='show-all'`且`treeCheckStrictly=False`，或者`showCheckedStrategy='show-parent'`，则`maxCount`无效.

    - maxTagCount (number | a value equal to: 'responsive'; optional):
        当`multiple=True`时，已选值tag展示的最大数量.

    - maxTagPlaceholder (a list of or a singular dash component, string or number; optional):
        当`multiple=True`时，隐藏已选值tag时显示的内容.

    - maxTagTextLength (number; optional):
        当`multiple=True`时，最大显示的已选值tag文本长度.

    - listHeight (number; default 256):
        选择菜单最大像素高度 默认值：`256`.

    - multiple (boolean; default False):
        是否开启多选模式 默认值：`False`.

    - suffixIcon (a list of or a singular dash component, string or number; optional):
        组件型，自定义的选择框后缀图标.

    - switcherIcon (a list of or a singular dash component, string or number; optional):
        组件型，自定义树节点的展开/折叠图标.

    - treeCheckable (boolean; default False):
        树节点是否可勾选 默认值：`False`.

    - treeCheckStrictly (boolean; default False):
        节点与其后代节点之间的选择行为是否彼此独立 默认值：`False`.

    - treeDefaultExpandAll (boolean; default False):
        初始化是否展开全部节点 默认值：`False`.

    - treeDefaultExpandedKeys (list of strings; optional):
        初始化已展开节点`key`值数组.

    - treeExpandedKeys (list of strings; optional):
        监听或设置已展开节点`key`值数组.

    - virtual (boolean; default True):
        是否开启虚拟滚动 默认值：`True`.

    - status (a value equal to: 'error', 'warning'; optional):
        控制校验状态，可选项有`'error'`、`'warning'`.

    - allowClear (boolean; default True):
        是否允许一键清空已选值 默认值：`True`.

    - treeNodeFilterProp (a value equal to: 'title', 'value'; default 'value'):
        基于搜索框中输入内容进行搜索的目标字段，可选项有`'value'`、`'title'` 默认值：`'value'`.

    - treeNodeFilterMode (a value equal to: 'case-insensitive', 'case-sensitive', 'regex'; default 'case-insensitive'):
        搜索匹配模式，可选项有`'case-insensitive'`（大小写不敏感）、`'case-sensitive'`（大小写敏感）、`'regex'`（正则表达式）
        默认值：`'case-insensitive'`.

    - autoClearSearchValue (boolean; default True):
        当`multiple=True`时，设置是否在选中项后自动清空搜索框中的内容 默认值：`True`.

    - showCheckedStrategy (a value equal to: 'show-all', 'show-parent', 'show-child'; default 'show-all'):
        已选项回填搜索框策略，可选项有`'show-all'`、`'show-parent'`、`'show-child'`
        默认值：`'show-all'`.

    - dropdownBefore (a list of or a singular dash component, string or number; optional):
        组件型，选择菜单前缀内容.

    - dropdownAfter (a list of or a singular dash component, string or number; optional):
        组件型，选择菜单后缀内容.

    - prefix (a list of or a singular dash component, string or number; optional):
        组件型，前缀内嵌内容.

    - readOnly (boolean; optional):
        是否渲染为只读状态 默认值：`False`.

    - enableAsyncLoad (boolean; default False):
        是否开启子节点异步加载功能，开启后无`children`属性，且未设置`isLeaf`为`True`的节点将可展开并触发`loadingNode`事件更新
        默认值：`False`.

    - loadingNode (dict; optional):
        监听触发异步数据加载的节点展开事件信息.

    - popupContainer (a value equal to: 'parent', 'body'; default 'body'):
        相关展开层锚定策略，可选项有`'parent'`、`'body'` 默认值：`'body'`.

    - batchPropsNames (list of strings; optional):
        需要纳入[批量属性监听](/batch-props-values)的若干属性名.

    - batchPropsValues (dict; optional):
        监听`batchPropsNames`中指定的若干属性值.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配.

    - loading_state (dict; optional)

        `loading_state` is a dict with keys:

        - is_loading (boolean; optional):
            Determines if the component is loading or not.

        - prop_name (string; optional):
            Holds which property is loading.

        - component_name (string; optional):
            Holds the name of the component that is loading.

    - persistence (boolean | string | number; optional):
        是否开启[属性持久化](/prop-persistence).

    - persisted_props (list of a value equal to: 'value's; optional):
        开启属性持久化功能的若干属性名，可选项有`'value'` 默认值：`['value']`.

    - persistence_type (a value equal to: 'local', 'session', 'memory'; optional):
        属性持久化存储类型，可选项有`'local'`（本地持久化），`'session'`（会话持久化），`'memory'`（内存持久化）
        默认值：`'local'`."""

    _children_props: typing.List[str] = [
        'treeNodeKeyToTitle{}',
        'maxTagPlaceholder',
        'suffixIcon',
        'switcherIcon',
        'dropdownBefore',
        'dropdownAfter',
        'prefix',
    ]
    _base_nodes = [
        'maxTagPlaceholder',
        'suffixIcon',
        'switcherIcon',
        'dropdownBefore',
        'dropdownAfter',
        'prefix',
        'children',
    ]
    _namespace = 'feffery_antd_components'
    _type = 'AntdTreeSelect'
    LoadingState = TypedDict(
        'LoadingState',
        {
            'is_loading': NotRequired[bool],
            'prop_name': NotRequired[str],
            'component_name': NotRequired[str],
        },
    )

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        popupClassName: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        enableBatchControl: typing.Optional[bool] = None,
        locale: typing.Optional[Literal['zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr']] = None,
        treeDataMode: typing.Optional[Literal['tree', 'flat']] = None,
        treeData: typing.Optional[typing.Union[typing.Any, typing.Sequence[typing.Any]]] = None,
        treeNodeKeyToTitle: typing.Optional[
            typing.Dict[typing.Union[str, float, int], ComponentType]
        ] = None,
        disabled: typing.Optional[bool] = None,
        size: typing.Optional[Literal['small', 'middle', 'large']] = None,
        bordered: typing.Optional[bool] = None,
        variant: typing.Optional[Literal['outlined', 'borderless', 'filled', 'underlined']] = None,
        placeholder: typing.Optional[str] = None,
        placement: typing.Optional[
            Literal['bottomLeft', 'bottomRight', 'topLeft', 'topRight']
        ] = None,
        treeLine: typing.Optional[bool] = None,
        value: typing.Optional[
            typing.Union[str, NumberType, typing.Sequence[typing.Union[str, NumberType]]]
        ] = None,
        defaultValue: typing.Optional[
            typing.Union[str, NumberType, typing.Sequence[typing.Union[str, NumberType]]]
        ] = None,
        maxCount: typing.Optional[NumberType] = None,
        maxTagCount: typing.Optional[typing.Union[NumberType, Literal['responsive']]] = None,
        maxTagPlaceholder: typing.Optional[ComponentType] = None,
        maxTagTextLength: typing.Optional[NumberType] = None,
        listHeight: typing.Optional[NumberType] = None,
        multiple: typing.Optional[bool] = None,
        suffixIcon: typing.Optional[ComponentType] = None,
        switcherIcon: typing.Optional[ComponentType] = None,
        treeCheckable: typing.Optional[bool] = None,
        treeCheckStrictly: typing.Optional[bool] = None,
        treeDefaultExpandAll: typing.Optional[bool] = None,
        treeDefaultExpandedKeys: typing.Optional[typing.Sequence[str]] = None,
        treeExpandedKeys: typing.Optional[typing.Sequence[str]] = None,
        virtual: typing.Optional[bool] = None,
        status: typing.Optional[Literal['error', 'warning']] = None,
        allowClear: typing.Optional[bool] = None,
        treeNodeFilterProp: typing.Optional[Literal['title', 'value']] = None,
        treeNodeFilterMode: typing.Optional[
            Literal['case-insensitive', 'case-sensitive', 'regex']
        ] = None,
        autoClearSearchValue: typing.Optional[bool] = None,
        showCheckedStrategy: typing.Optional[
            Literal['show-all', 'show-parent', 'show-child']
        ] = None,
        dropdownBefore: typing.Optional[ComponentType] = None,
        dropdownAfter: typing.Optional[ComponentType] = None,
        prefix: typing.Optional[ComponentType] = None,
        readOnly: typing.Optional[bool] = None,
        enableAsyncLoad: typing.Optional[bool] = None,
        loadingNode: typing.Optional[dict] = None,
        popupContainer: typing.Optional[Literal['parent', 'body']] = None,
        batchPropsNames: typing.Optional[typing.Sequence[str]] = None,
        batchPropsValues: typing.Optional[dict] = None,
        loading_state: typing.Optional['LoadingState'] = None,
        persistence: typing.Optional[typing.Union[bool, str, NumberType]] = None,
        persisted_props: typing.Optional[typing.Sequence[Literal['value']]] = None,
        persistence_type: typing.Optional[Literal['local', 'session', 'memory']] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'popupClassName',
            'name',
            'enableBatchControl',
            'locale',
            'treeDataMode',
            'treeData',
            'treeNodeKeyToTitle',
            'disabled',
            'size',
            'bordered',
            'variant',
            'placeholder',
            'placement',
            'treeLine',
            'value',
            'defaultValue',
            'maxCount',
            'maxTagCount',
            'maxTagPlaceholder',
            'maxTagTextLength',
            'listHeight',
            'multiple',
            'suffixIcon',
            'switcherIcon',
            'treeCheckable',
            'treeCheckStrictly',
            'treeDefaultExpandAll',
            'treeDefaultExpandedKeys',
            'treeExpandedKeys',
            'virtual',
            'status',
            'allowClear',
            'treeNodeFilterProp',
            'treeNodeFilterMode',
            'autoClearSearchValue',
            'showCheckedStrategy',
            'dropdownBefore',
            'dropdownAfter',
            'prefix',
            'readOnly',
            'enableAsyncLoad',
            'loadingNode',
            'popupContainer',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
            'loading_state',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'popupClassName',
            'name',
            'enableBatchControl',
            'locale',
            'treeDataMode',
            'treeData',
            'treeNodeKeyToTitle',
            'disabled',
            'size',
            'bordered',
            'variant',
            'placeholder',
            'placement',
            'treeLine',
            'value',
            'defaultValue',
            'maxCount',
            'maxTagCount',
            'maxTagPlaceholder',
            'maxTagTextLength',
            'listHeight',
            'multiple',
            'suffixIcon',
            'switcherIcon',
            'treeCheckable',
            'treeCheckStrictly',
            'treeDefaultExpandAll',
            'treeDefaultExpandedKeys',
            'treeExpandedKeys',
            'virtual',
            'status',
            'allowClear',
            'treeNodeFilterProp',
            'treeNodeFilterMode',
            'autoClearSearchValue',
            'showCheckedStrategy',
            'dropdownBefore',
            'dropdownAfter',
            'prefix',
            'readOnly',
            'enableAsyncLoad',
            'loadingNode',
            'popupContainer',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
            'loading_state',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['treeData']:
            if k not in args:
                raise TypeError('Required argument `' + k + '` was not specified.')

        super(AntdTreeSelect, self).__init__(**args)


setattr(AntdTreeSelect, '__init__', _explicitize_args(AntdTreeSelect.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdSkeletonButton(Component):
    """An AntdSkeletonButton component.
    骨骼屏按钮占位图组件AntdSkeletonButton

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - active (boolean; default False):
        是否显示动画 默认值：`False`.

    - block (boolean; default False):
        是否撑满父容器 默认值：`False`.

    - shape (a value equal to: 'circle', 'round', 'default'; default 'default'):
        按钮占位图形状，可选项有`'circle'`、`'round'`、`'default'` 默认值：`'default'`.

    - size (a value equal to: 'large', 'small', 'default'; default 'default'):
        按钮占位图尺寸，可选项有`'large'`、`'small'`、`'default'` 默认值：`'default'`.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdSkeletonButton'

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        active: typing.Optional[bool] = None,
        block: typing.Optional[bool] = None,
        shape: typing.Optional[Literal['circle', 'round', 'default']] = None,
        size: typing.Optional[Literal['large', 'small', 'default']] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'active',
            'block',
            'shape',
            'size',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'active',
            'block',
            'shape',
            'size',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdSkeletonButton, self).__init__(**args)


setattr(AntdSkeletonButton, '__init__', _explicitize_args(AntdSkeletonButton.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdCountdown(Component):
    """An AntdCountdown component.
    倒计时组件AntdCountdown

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - format (string; optional):
        日期时间显示格式，[参考资料](https://day.js.org/docs/en/display/format)，如`HH:mm:ss`代表`时:分:秒`.

    - value (string; optional):
        目标截止日期时间字符串，与`valueFormat`对应.

    - valueFormat (string; default 'YYYY-MM-DD hh:mm:ss'):
        针对`value`设置对应的日期时间解析格式，[参考资料](https://day.js.org/docs/en/display/format)
        默认值：`'YYYY-MM-DD hh:mm:ss'`.

    - prefix (a list of or a singular dash component, string or number; optional):
        组件型，数值前缀内容.

    - suffix (a list of or a singular dash component, string or number; optional):
        组件型，数值后缀内容.

    - title (a list of or a singular dash component, string or number; optional):
        组件型，标题内容.

    - titleTooltip (string; optional):
        为标题内容添加额外鼠标悬停提示信息.

    - valueStyle (dict; optional):
        数值内容css样式.

    - finishEvent (dict; optional):
        监听倒计时结束事件.

        `finishEvent` is a dict with keys:

        - timestamp (number; optional):
            事件时间戳.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = ['prefix', 'suffix', 'title']
    _base_nodes = ['prefix', 'suffix', 'title', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdCountdown'
    FinishEvent = TypedDict('FinishEvent', {'timestamp': NotRequired[NumberType]})

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        format: typing.Optional[str] = None,
        value: typing.Optional[str] = None,
        valueFormat: typing.Optional[str] = None,
        prefix: typing.Optional[ComponentType] = None,
        suffix: typing.Optional[ComponentType] = None,
        title: typing.Optional[ComponentType] = None,
        titleTooltip: typing.Optional[str] = None,
        valueStyle: typing.Optional[dict] = None,
        finishEvent: typing.Optional['FinishEvent'] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'format',
            'value',
            'valueFormat',
            'prefix',
            'suffix',
            'title',
            'titleTooltip',
            'valueStyle',
            'finishEvent',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'format',
            'value',
            'valueFormat',
            'prefix',
            'suffix',
            'title',
            'titleTooltip',
            'valueStyle',
            'finishEvent',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdCountdown, self).__init__(**args)


setattr(AntdCountdown, '__init__', _explicitize_args(AntdCountdown.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdTitle(Component):
    """An AntdTitle component.
    标题组件AntdTitle

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，内嵌元素.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - locale (a value equal to: 'zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr'; default 'zh-cn'):
        组件文案语种，可选项有`'zh-cn'`（简体中文）、`'en-us'`（英语）、`'de-de'`（德语）、`'fr-fr'`（法语）、`'ru-ru'`（俄语）
        默认值：`'zh-cn'`.

    - level (number; default 1):
        标题级别，可选项有`1`、`2`、`3`、`4`、`5` 默认值：`1`.

    - code (boolean; optional):
        是否渲染为代码形式.

    - copyable (boolean; optional):
        是否开启快捷复制功能.

    - strikethrough (boolean; optional):
        是否渲染为删除线形式.

    - disabled (boolean; optional):
        是否渲染为禁用形式.

    - mark (boolean; optional):
        是否渲染为高亮形式.

    - strong (boolean; optional):
        是否渲染为加粗形式.

    - italic (boolean; optional):
        是否渲染为斜体形式.

    - underline (boolean; optional):
        是否渲染为下划线形式.

    - keyboard (boolean; optional):
        是否渲染为键盘形式.

    - type (a value equal to: 'secondary', 'success', 'warning', 'danger'; optional):
        设置内容特殊状态形式，可选项有`'secondary'`、`'success'`、`'warning'`、`'danger'`.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdTitle'

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        locale: typing.Optional[Literal['zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr']] = None,
        level: typing.Optional[NumberType] = None,
        code: typing.Optional[bool] = None,
        copyable: typing.Optional[bool] = None,
        strikethrough: typing.Optional[bool] = None,
        disabled: typing.Optional[bool] = None,
        mark: typing.Optional[bool] = None,
        strong: typing.Optional[bool] = None,
        italic: typing.Optional[bool] = None,
        underline: typing.Optional[bool] = None,
        keyboard: typing.Optional[bool] = None,
        type: typing.Optional[Literal['secondary', 'success', 'warning', 'danger']] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'locale',
            'level',
            'code',
            'copyable',
            'strikethrough',
            'disabled',
            'mark',
            'strong',
            'italic',
            'underline',
            'keyboard',
            'type',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'locale',
            'level',
            'code',
            'copyable',
            'strikethrough',
            'disabled',
            'mark',
            'strong',
            'italic',
            'underline',
            'keyboard',
            'type',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdTitle, self).__init__(children=children, **args)


setattr(AntdTitle, '__init__', _explicitize_args(AntdTitle.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdCopyText(Component):
    """An AntdCopyText component.
    文字复制组件AntdCopyText

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - locale (a value equal to: 'zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr'; default 'zh-cn'):
        组件文案语种，可选项有`'zh-cn'`（简体中文）、`'en-us'`（英语）、`'de-de'`（德语）、`'fr-fr'`（法语）、`'ru-ru'`（俄语）
        默认值：`'zh-cn'`.

    - text (string; default ''):
        复制目标内容.

    - format (a value equal to: 'text/plain', 'text/html'; default 'text/plain'):
        剪切板内容的类型，可选项有`'text/plain'`、`text/html` 默认值：`'text/plain'`.

    - tooltips (list of a list of or a singular dash component, string or numbers | boolean; optional):
        设置复制前后的文字提示内容，格式为`[复制前内容, 复制后内容]`，设置为`False`时关闭文字提示.

    - beforeIcon (a list of or a singular dash component, string or number; optional):
        组件型，未复制状态图标.

    - afterIcon (a list of or a singular dash component, string or number; optional):
        组件型，完成复制状态图标.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = ['tooltips', 'beforeIcon', 'afterIcon']
    _base_nodes = ['tooltips', 'beforeIcon', 'afterIcon', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdCopyText'

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        locale: typing.Optional[Literal['zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr']] = None,
        text: typing.Optional[str] = None,
        format: typing.Optional[Literal['text/plain', 'text/html']] = None,
        tooltips: typing.Optional[typing.Union[typing.Sequence[ComponentType], bool]] = None,
        beforeIcon: typing.Optional[ComponentType] = None,
        afterIcon: typing.Optional[ComponentType] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'locale',
            'text',
            'format',
            'tooltips',
            'beforeIcon',
            'afterIcon',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'locale',
            'text',
            'format',
            'tooltips',
            'beforeIcon',
            'afterIcon',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdCopyText, self).__init__(**args)


setattr(AntdCopyText, '__init__', _explicitize_args(AntdCopyText.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdSider(Component):
    """An AntdSider component.
    侧边栏组件AntdSider

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，内嵌元素.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - collapsed (boolean; optional):
        当前是否收起.

    - collapsedWidth (number; default 80):
        收起后呈现的像素宽度，设置为0时会额外渲染特殊触发组件 默认值：`80`.

    - collapsible (boolean; default False):
        是否可收起 默认值：`False`.

    - reverseArrow (boolean; default False):
        是否翻转收起箭头的方向，通常在Sider位于右侧时使用 默认值：`False`.

    - theme (a value equal to: 'light', 'dark'; default 'dark'):
        主题，可选项有`'light'`、`'dark'` 默认值：`'dark'`.

    - width (number | string; default 200):
        侧边栏像素宽度 默认值：`200`.

    - trigger (a list of or a singular dash component, string or number; optional):
        设置为`None`时不渲染自带的特殊触发组件.

    - breakpoint (a value equal to: 'xs', 'sm', 'md', 'lg', 'xl', 'xxl'; optional):
        侧边栏自动收起对应的响应式断点.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = ['trigger']
    _base_nodes = ['trigger', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdSider'

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        collapsed: typing.Optional[bool] = None,
        collapsedWidth: typing.Optional[NumberType] = None,
        collapsible: typing.Optional[bool] = None,
        reverseArrow: typing.Optional[bool] = None,
        theme: typing.Optional[Literal['light', 'dark']] = None,
        width: typing.Optional[typing.Union[NumberType, str]] = None,
        trigger: typing.Optional[ComponentType] = None,
        breakpoint: typing.Optional[Literal['xs', 'sm', 'md', 'lg', 'xl', 'xxl']] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'collapsed',
            'collapsedWidth',
            'collapsible',
            'reverseArrow',
            'theme',
            'width',
            'trigger',
            'breakpoint',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'collapsed',
            'collapsedWidth',
            'collapsible',
            'reverseArrow',
            'theme',
            'width',
            'trigger',
            'breakpoint',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdSider, self).__init__(children=children, **args)


setattr(AntdSider, '__init__', _explicitize_args(AntdSider.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdDescriptionItem(Component):
    """An AntdDescriptionItem component.
    描述列表子项组件AntdDescriptionItem

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，内嵌元素.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - styles (dict; optional):
        细分控制子元素css样式.

        `styles` is a dict with keys:

        - label (dict; optional):
            标签元素css样式.

        - content (dict; optional):
            内容元素css样式.

    - classNames (dict; optional):
        细分控制子元素css类名.

        `classNames` is a dict with keys:

        - label (string; optional):
            标签元素css类名.

        - content (string; optional):
            内容元素css类名.

    - label (a list of or a singular dash component, string or number; optional):
        组件型，标题内容.

    - span (number; default 1):
        所占宽度份数 默认值：`1`.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = ['label']
    _base_nodes = ['label', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdDescriptionItem'
    Styles = TypedDict('Styles', {'label': NotRequired[dict], 'content': NotRequired[dict]})

    ClassNames = TypedDict('ClassNames', {'label': NotRequired[str], 'content': NotRequired[str]})

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        styles: typing.Optional['Styles'] = None,
        classNames: typing.Optional['ClassNames'] = None,
        label: typing.Optional[ComponentType] = None,
        span: typing.Optional[NumberType] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'styles',
            'classNames',
            'label',
            'span',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'styles',
            'classNames',
            'label',
            'span',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdDescriptionItem, self).__init__(children=children, **args)


setattr(AntdDescriptionItem, '__init__', _explicitize_args(AntdDescriptionItem.__init__))



from .AntdAccordion import AntdAccordion
from .AntdAffix import AntdAffix
from .AntdAlert import AntdAlert
from .AntdAnchor import AntdAnchor
from .AntdAvatar import AntdAvatar
from .AntdAvatarGroup import AntdAvatarGroup
from .AntdBackTop import AntdBackTop
from .AntdBadge import AntdBadge
from .AntdBreadcrumb import AntdBreadcrumb
from .AntdButton import AntdButton
from .AntdCalendar import AntdCalendar
from .AntdCard import AntdCard
from .AntdCardGrid import AntdCardGrid
from .AntdCardMeta import AntdCardMeta
from .AntdCarousel import AntdCarousel
from .AntdCascader import AntdCascader
from .AntdCenter import AntdCenter
from .AntdCheckableTag import AntdCheckableTag
from .AntdCheckbox import AntdCheckbox
from .AntdCheckboxGroup import AntdCheckboxGroup
from .AntdCheckCard import AntdCheckCard
from .AntdCheckCardGroup import AntdCheckCardGroup
from .AntdCol import AntdCol
from .AntdCollapse import AntdCollapse
from .AntdColorPicker import AntdColorPicker
from .AntdComment import AntdComment
from .AntdCompact import AntdCompact
from .AntdConfigProvider import AntdConfigProvider
from .AntdContent import AntdContent
from .AntdCopyText import AntdCopyText
from .AntdCountdown import AntdCountdown
from .AntdCountup import AntdCountup
from .AntdCustomSkeleton import AntdCustomSkeleton
from .AntdDatePicker import AntdDatePicker
from .AntdDateRangePicker import AntdDateRangePicker
from .AntdDescriptionItem import AntdDescriptionItem
from .AntdDescriptions import AntdDescriptions
from .AntdDivider import AntdDivider
from .AntdDraggerUpload import AntdDraggerUpload
from .AntdDrawer import AntdDrawer
from .AntdDropdown import AntdDropdown
from .AntdEmpty import AntdEmpty
from .AntdFlex import AntdFlex
from .AntdFloatButton import AntdFloatButton
from .AntdFloatButtonGroup import AntdFloatButtonGroup
from .AntdFooter import AntdFooter
from .AntdForm import AntdForm
from .AntdFormItem import AntdFormItem
from .AntdFormRender import AntdFormRender
from .AntdHappyProvider import AntdHappyProvider
from .AntdHeader import AntdHeader
from .AntdIcon import AntdIcon
from .AntdImage import AntdImage
from .AntdImageGroup import AntdImageGroup
from .AntdInput import AntdInput
from .AntdInputNumber import AntdInputNumber
from .AntdLayout import AntdLayout
from .AntdMentions import AntdMentions
from .AntdMenu import AntdMenu
from .AntdMessage import AntdMessage
from .AntdModal import AntdModal
from .AntdNotification import AntdNotification
from .AntdOTP import AntdOTP
from .AntdPageHeader import AntdPageHeader
from .AntdPagination import AntdPagination
from .AntdParagraph import AntdParagraph
from .AntdPictureUpload import AntdPictureUpload
from .AntdPopconfirm import AntdPopconfirm
from .AntdPopover import AntdPopover
from .AntdPopupCard import AntdPopupCard
from .AntdProgress import AntdProgress
from .AntdQRCode import AntdQRCode
from .AntdRadioGroup import AntdRadioGroup
from .AntdRate import AntdRate
from .AntdResult import AntdResult
from .AntdRibbon import AntdRibbon
from .AntdRow import AntdRow
from .AntdSegmented import AntdSegmented
from .AntdSegmentedColoring import AntdSegmentedColoring
from .AntdSelect import AntdSelect
from .AntdSider import AntdSider
from .AntdSkeleton import AntdSkeleton
from .AntdSkeletonAvatar import AntdSkeletonAvatar
from .AntdSkeletonButton import AntdSkeletonButton
from .AntdSkeletonImage import AntdSkeletonImage
from .AntdSkeletonInput import AntdSkeletonInput
from .AntdSlider import AntdSlider
from .AntdSpace import AntdSpace
from .AntdSpin import AntdSpin
from .AntdSplitter import AntdSplitter
from .AntdSpoiler import AntdSpoiler
from .AntdStatistic import AntdStatistic
from .AntdSteps import AntdSteps
from .AntdSwitch import AntdSwitch
from .AntdTable import AntdTable
from .AntdTabs import AntdTabs
from .AntdTag import AntdTag
from .AntdText import AntdText
from .AntdTimeline import AntdTimeline
from .AntdTimePicker import AntdTimePicker
from .AntdTimeRangePicker import AntdTimeRangePicker
from .AntdTitle import AntdTitle
from .AntdTooltip import AntdTooltip
from .AntdTour import AntdTour
from .AntdTransfer import AntdTransfer
from .AntdTree import AntdTree
from .AntdTreeSelect import AntdTreeSelect
from .AntdUpload import AntdUpload
from .AntdWatermark import AntdWatermark
from .Fragment import Fragment

__all__ = [
    'AntdAccordion',
    'AntdAvatar',
    'AntdAvatarGroup',
    'AntdBadge',
    'AntdCarousel',
    'AntdCheckableTag',
    'AntdCollapse',
    'AntdComment',
    'AntdCountdown',
    'AntdCountup',
    'AntdEmpty',
    'AntdImage',
    'AntdImageGroup',
    'AntdPopover',
    'AntdQRCode',
    'AntdRibbon',
    'AntdSegmented',
    'AntdSpoiler',
    'AntdStatistic',
    'AntdTable',
    'AntdTabs',
    'AntdTag',
    'AntdTimeline',
    'AntdTooltip',
    'AntdTree',
    'AntdCard',
    'AntdCardGrid',
    'AntdCardMeta',
    'AntdDescriptionItem',
    'AntdDescriptions',
    'AntdCalendar',
    'AntdCascader',
    'AntdCheckbox',
    'AntdCheckboxGroup',
    'AntdColorPicker',
    'AntdDatePicker',
    'AntdDateRangePicker',
    'AntdInput',
    'AntdInputNumber',
    'AntdMentions',
    'AntdOTP',
    'AntdRadioGroup',
    'AntdRate',
    'AntdSegmentedColoring',
    'AntdSelect',
    'AntdSlider',
    'AntdSwitch',
    'AntdTimePicker',
    'AntdTimeRangePicker',
    'AntdTransfer',
    'AntdTreeSelect',
    'AntdCheckCard',
    'AntdCheckCardGroup',
    'AntdForm',
    'AntdFormItem',
    'AntdDraggerUpload',
    'AntdPictureUpload',
    'AntdUpload',
    'AntdAlert',
    'AntdDrawer',
    'AntdMessage',
    'AntdModal',
    'AntdNotification',
    'AntdPopconfirm',
    'AntdPopupCard',
    'AntdProgress',
    'AntdResult',
    'AntdSpin',
    'AntdCustomSkeleton',
    'AntdSkeleton',
    'AntdSkeletonAvatar',
    'AntdSkeletonButton',
    'AntdSkeletonImage',
    'AntdSkeletonInput',
    'AntdFormRender',
    'AntdButton',
    'AntdFloatButton',
    'AntdFloatButtonGroup',
    'AntdIcon',
    'AntdParagraph',
    'AntdText',
    'AntdTitle',
    'AntdCenter',
    'AntdCompact',
    'AntdContent',
    'AntdDivider',
    'AntdFlex',
    'AntdFooter',
    'AntdHeader',
    'AntdLayout',
    'AntdSider',
    'AntdSpace',
    'AntdSplitter',
    'AntdCol',
    'AntdRow',
    'AntdAnchor',
    'AntdBreadcrumb',
    'AntdDropdown',
    'AntdMenu',
    'AntdPageHeader',
    'AntdPagination',
    'AntdSteps',
    'AntdAffix',
    'AntdBackTop',
    'AntdConfigProvider',
    'AntdCopyText',
    'AntdHappyProvider',
    'AntdTour',
    'AntdWatermark',
    'Fragment',
]



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdDescriptions(Component):
    """An AntdDescriptions component.
    描述列表组件AntdDescriptions

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，传入内部各描述列表子项.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - styles (dict; optional):
        细分控制子元素css样式.

        `styles` is a dict with keys:

        - root (dict; optional):
            根元素css样式.

        - header (dict; optional):
            头部元素css样式.

        - title (dict; optional):
            标题元素css样式.

        - extra (dict; optional):
            额外内容css样式.

        - label (dict; optional):
            标签元素css样式.

        - content (dict; optional):
            内容元素css样式.

    - classNames (dict; optional):
        细分控制子元素css类名.

        `classNames` is a dict with keys:

        - root (string; optional):
            根元素css类名.

        - header (string; optional):
            头部元素css类名.

        - title (string; optional):
            标题元素css类名.

        - extra (string; optional):
            额外内容css类名.

        - label (string; optional):
            标签元素css类名.

        - content (string; optional):
            内容元素css类名.

    - items (list of dicts; optional):
        配置描述列表子项，优先级高于`children`.

        `items` is a list of dicts with keys:

        - label (a list of or a singular dash component, string or number; optional):
            组件型，子项标题内容.

        - span (number | a value equal to: 'filled'; optional):
            子项所占宽度份数，当设置为`'filled'`时会自适应占满当前行剩余可用空间 默认值：`1`.

        - children (a list of or a singular dash component, string or number; optional):
            组件型，子项内容.

        - style (dict; optional):
            子项css样式.

        - className (string; optional):
            子项css类名.

    - title (a list of or a singular dash component, string or number; optional):
        组件型，标题内容.

    - column (dict; default 3):
        每行显示的字段项数量，支持响应式 默认值：`3`.

        `column` is a number | dict with keys:

        - xxl (number; optional)

        - xl (number; optional)

        - lg (number; optional)

        - md (number; optional)

        - sm (number; optional)

        - xs (number; optional)

    - bordered (boolean; default False):
        是否显示边框 默认值：`False`.

    - size (a value equal to: 'small', 'default', 'large'; default 'default'):
        整体尺寸规格，可选项有`'small'`、`'default'`、`'large'` 默认值：`'default'`.

    - layout (a value equal to: 'horizontal', 'vertical'; default 'horizontal'):
        布局方式，可选项有`'horizontal'`、`'vertical'` 默认值：`'horizontal'`.

    - extra (a list of or a singular dash component, string or number; optional):
        组件型，设置操作区域，显示在右上方.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = ['items[].label', 'items[].children', 'title', 'extra']
    _base_nodes = ['title', 'extra', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdDescriptions'
    Styles = TypedDict(
        'Styles',
        {
            'root': NotRequired[dict],
            'header': NotRequired[dict],
            'title': NotRequired[dict],
            'extra': NotRequired[dict],
            'label': NotRequired[dict],
            'content': NotRequired[dict],
        },
    )

    ClassNames = TypedDict(
        'ClassNames',
        {
            'root': NotRequired[str],
            'header': NotRequired[str],
            'title': NotRequired[str],
            'extra': NotRequired[str],
            'label': NotRequired[str],
            'content': NotRequired[str],
        },
    )

    Items = TypedDict(
        'Items',
        {
            'label': NotRequired[ComponentType],
            'span': NotRequired[typing.Union[NumberType, Literal['filled']]],
            'children': NotRequired[ComponentType],
            'style': NotRequired[dict],
            'className': NotRequired[str],
        },
    )

    Column = TypedDict(
        'Column',
        {
            'xxl': NotRequired[NumberType],
            'xl': NotRequired[NumberType],
            'lg': NotRequired[NumberType],
            'md': NotRequired[NumberType],
            'sm': NotRequired[NumberType],
            'xs': NotRequired[NumberType],
        },
    )

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        styles: typing.Optional['Styles'] = None,
        classNames: typing.Optional['ClassNames'] = None,
        items: typing.Optional[typing.Sequence['Items']] = None,
        title: typing.Optional[ComponentType] = None,
        column: typing.Optional[typing.Union[NumberType, 'Column']] = None,
        bordered: typing.Optional[bool] = None,
        size: typing.Optional[Literal['small', 'default', 'large']] = None,
        layout: typing.Optional[Literal['horizontal', 'vertical']] = None,
        extra: typing.Optional[ComponentType] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'styles',
            'classNames',
            'items',
            'title',
            'column',
            'bordered',
            'size',
            'layout',
            'extra',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'styles',
            'classNames',
            'items',
            'title',
            'column',
            'bordered',
            'size',
            'layout',
            'extra',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdDescriptions, self).__init__(children=children, **args)


setattr(AntdDescriptions, '__init__', _explicitize_args(AntdDescriptions.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdDivider(Component):
    """An AntdDivider component.
    分割线组件AntdDivider

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，分割线内嵌元素.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - innerTextOrientation (a value equal to: 'left', 'center', 'right'; default 'center'):
        内嵌元素对齐方式，可选项有`'left'`、`'center'`、`'right'` 默认值：`'center'`.

    - isDashed (boolean; default False):
        是否渲染为虚线形式 默认值：`False`.

    - direction (a value equal to: 'horizontal', 'vertical'; default 'horizontal'):
        分割线方向，可选项有`'horizontal'`、`'vertical'` 默认值：`'horizontal'`.

    - fontSize (string | number; optional):
        内嵌元素字体大小.

    - lineColor (string; optional):
        分割线颜色.

    - fontStyle (string; optional):
        内嵌元素字体风格.

    - fontWeight (string; optional):
        内嵌元素字重.

    - fontFamily (string; optional):
        内嵌元素字体.

    - fontColor (string; optional):
        内嵌元素字体颜色.

    - variant (a value equal to: 'dashed', 'dotted', 'solid'; default 'solid'):
        分割线变体，可选项有`'dashed'`（虚线）、`'dotted'`（点线）、`'solid'`（实线）
        默认值：`'solid'`.

    - plain (boolean; default True):
        文字内容是否呈现为常规正文形式 默认值：`True`.

    - size (a value equal to: 'small', 'middle', 'large'; optional):
        间距大小，仅当``direction='horizontal'``时有效，可选项有`'small'`、`'middle'`、`'large'`.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = []
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdDivider'

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        style: typing.Optional[typing.Any] = None,
        innerTextOrientation: typing.Optional[Literal['left', 'center', 'right']] = None,
        isDashed: typing.Optional[bool] = None,
        direction: typing.Optional[Literal['horizontal', 'vertical']] = None,
        fontSize: typing.Optional[typing.Union[str, NumberType]] = None,
        lineColor: typing.Optional[str] = None,
        fontStyle: typing.Optional[str] = None,
        fontWeight: typing.Optional[str] = None,
        fontFamily: typing.Optional[str] = None,
        fontColor: typing.Optional[str] = None,
        variant: typing.Optional[Literal['dashed', 'dotted', 'solid']] = None,
        plain: typing.Optional[bool] = None,
        size: typing.Optional[Literal['small', 'middle', 'large']] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'children',
            'className',
            'style',
            'innerTextOrientation',
            'isDashed',
            'direction',
            'fontSize',
            'lineColor',
            'fontStyle',
            'fontWeight',
            'fontFamily',
            'fontColor',
            'variant',
            'plain',
            'size',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'children',
            'className',
            'style',
            'innerTextOrientation',
            'isDashed',
            'direction',
            'fontSize',
            'lineColor',
            'fontStyle',
            'fontWeight',
            'fontFamily',
            'fontColor',
            'variant',
            'plain',
            'size',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdDivider, self).__init__(children=children, **args)


setattr(AntdDivider, '__init__', _explicitize_args(AntdDivider.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdComment(Component):
    """An AntdComment component.
    评论组件AntdComment

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - children (a list of or a singular dash component, string or number; optional):
        传入内部嵌套的评论组件.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - locale (a value equal to: 'zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr'; default 'zh-cn'):
        组件文案语种，可选项有`'zh-cn'`（简体中文）、`'en-us'`（英语）、`'de-de'`（德语）、`'fr-fr'`（法语）、`'ru-ru'`（俄语）
        默认值：`'zh-cn'`.

    - commentId (string; optional):
        评论唯一id，可用于数据库匹配等场景.

    - authorName (string; optional):
        评论发布用户名.

    - authorNameHref (string; optional):
        评论发布用户名附带链接地址.

    - publishTime (dict; required):
        必填，配置发布日期时间相关参数.

        `publishTime` is a dict with keys:

        - value (string; required):
            必填，日期时间字符串.

        - format (string; optional):
            与日期时间字符串匹配的格式.

    - fromNow (boolean; default False):
        是否以相对时间格式呈现发布日期时间.

    - showLikeDislike (boolean; default True):
        是否显示“支持/反对”按钮 默认值：`True`.

    - showReply (boolean; default True):
        是否显示“添加回复”按钮 默认值：`True`.

    - showDelete (boolean; default False):
        是否显示“删除”按钮 默认值：`False`.

    - replyClicks (number; default 0):
        监听“添加回复”按钮累计点击次数 默认值：`0`.

    - deleteClicks (number; default 0):
        监听“删除”按钮累计点击次数 默认值：`0`.

    - commentContent (a list of or a singular dash component, string or number; optional):
        组件型，评论正文内容.

    - likesCount (number; default 0):
        监听或设置“支持”次数.

    - dislikesCount (number; default 0):
        监听或设置“反对”次数.

    - action (a value equal to: 'liked', 'disliked', 'default'; optional):
        监听或设置当前评论“支持/反对”状态，可选项有`'liked'`、`'disliked'`、`'default'`
        默认值：`'default'`.

    - defaultAction (a value equal to: 'liked', 'disliked', 'default'; optional):
        设置当前评论初始化时的“支持/反对”状态，可选项有`'liked'`、`'disliked'`、`'default'`.

    - avatarProps (dict; optional):
        配置评论用户头像，同`AntdAvatar`.

    - popupContainer (a value equal to: 'parent', 'body'; default 'body'):
        相关展开层锚定策略，可选项有`'parent'`、`'body'` 默认值：`'body'`.

    - batchPropsNames (list of strings; optional):
        需要纳入[批量属性监听](/batch-props-values)的若干属性名.

    - batchPropsValues (dict; optional):
        监听`batchPropsNames`中指定的若干属性值.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配.

    - loading_state (dict; optional)

        `loading_state` is a dict with keys:

        - is_loading (boolean; optional):
            Determines if the component is loading or not.

        - prop_name (string; optional):
            Holds which property is loading.

        - component_name (string; optional):
            Holds the name of the component that is loading."""

    _children_props: typing.List[str] = ['commentContent']
    _base_nodes = ['commentContent', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdComment'
    PublishTime = TypedDict('PublishTime', {'value': str, 'format': NotRequired[str]})

    LoadingState = TypedDict(
        'LoadingState',
        {
            'is_loading': NotRequired[bool],
            'prop_name': NotRequired[str],
            'component_name': NotRequired[str],
        },
    )

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        locale: typing.Optional[Literal['zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr']] = None,
        commentId: typing.Optional[str] = None,
        authorName: typing.Optional[str] = None,
        authorNameHref: typing.Optional[str] = None,
        publishTime: typing.Optional['PublishTime'] = None,
        fromNow: typing.Optional[bool] = None,
        showLikeDislike: typing.Optional[bool] = None,
        showReply: typing.Optional[bool] = None,
        showDelete: typing.Optional[bool] = None,
        replyClicks: typing.Optional[NumberType] = None,
        deleteClicks: typing.Optional[NumberType] = None,
        commentContent: typing.Optional[ComponentType] = None,
        likesCount: typing.Optional[NumberType] = None,
        dislikesCount: typing.Optional[NumberType] = None,
        action: typing.Optional[Literal['liked', 'disliked', 'default']] = None,
        defaultAction: typing.Optional[Literal['liked', 'disliked', 'default']] = None,
        avatarProps: typing.Optional[dict] = None,
        popupContainer: typing.Optional[Literal['parent', 'body']] = None,
        batchPropsNames: typing.Optional[typing.Sequence[str]] = None,
        batchPropsValues: typing.Optional[dict] = None,
        loading_state: typing.Optional['LoadingState'] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'children',
            'key',
            'style',
            'className',
            'locale',
            'commentId',
            'authorName',
            'authorNameHref',
            'publishTime',
            'fromNow',
            'showLikeDislike',
            'showReply',
            'showDelete',
            'replyClicks',
            'deleteClicks',
            'commentContent',
            'likesCount',
            'dislikesCount',
            'action',
            'defaultAction',
            'avatarProps',
            'popupContainer',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
            'loading_state',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'children',
            'key',
            'style',
            'className',
            'locale',
            'commentId',
            'authorName',
            'authorNameHref',
            'publishTime',
            'fromNow',
            'showLikeDislike',
            'showReply',
            'showDelete',
            'replyClicks',
            'deleteClicks',
            'commentContent',
            'likesCount',
            'dislikesCount',
            'action',
            'defaultAction',
            'avatarProps',
            'popupContainer',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
            'loading_state',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        for k in ['publishTime']:
            if k not in args:
                raise TypeError('Required argument `' + k + '` was not specified.')

        super(AntdComment, self).__init__(children=children, **args)


setattr(AntdComment, '__init__', _explicitize_args(AntdComment.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdForm(Component):
    """An AntdForm component.
    表单组件AntdForm

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，内嵌相关`AntdFormItem`组件或常用表单输入类组件.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - layout (a value equal to: 'horizontal', 'vertical', 'inline'; default 'horizontal'):
        表单布局模式，可选项有`'horizontal'`、`'vertical'`、`'inline'`
        默认值：`'horizontal'`.

    - labelCol (dict; optional):
        配置表单项标签部分相关参数.

        `labelCol` is a dict with keys:

        - span (number; optional):
            标签部分所占宽度份数（总份数24）.

        - offset (number; optional):
            标签部分向右偏移宽度份数.

        - flex (string | number; optional):
            同css中的flex属性，用于更灵活的控制标签部分所占宽度.

    - wrapperCol (dict; optional):
        配置表单项控件部分相关参数.

        `wrapperCol` is a dict with keys:

        - span (number; optional):
            控件部分所占宽度份数（总份数24）.

        - offset (number; optional):
            控件部分向右偏移宽度份数.

        - flex (string | number; optional):
            同css中的flex属性，用于更灵活的控制控件部分所占宽度.

    - colon (boolean; default True):
        当`layput='horizontal'`时，控制是否在表单项标签部分末尾添加冒号.

    - labelAlign (a value equal to: 'left', 'right'; default 'right'):
        表单项标签部分文本对齐方式，可选项有`'left'`、`'right'` 默认值：`'right'`.

    - labelWrap (boolean; default False):
        针对超长表单项标签是否允许换行 默认值：`False`.

    - enableBatchControl (boolean; default False):
        是否启用表单批量控制功能，开启后会导致部分性能的损耗 默认值：`False`.

    - values (dict; optional):
        当`enableBatchControl=True`时，可用于监听或设置搜集内部表单输入类组件的输入值变化情况，开启后内部表单输入类组件自身的`defaultValue`、`value`参数将会失效.

    - validateStatuses (dict with strings as keys and values of type a value equal to: 'success', 'warning', 'error', 'validating'; optional):
        当`enableBatchControl=True`时，可用于统一设置内部各`AntdFormItem`组件的`validateStatus`值，键为对应`AntdFormItem`组件的`label`值，优先级低于各`AntdFormItem`组件的`validateStatus`值.

    - helps (dict with strings as keys and values of type a list of or a singular dash component, string or number; optional):
        当`enableBatchControl=True`时，可用于统一设置内部各`AntdFormItem`组件的`help`值，键为对应`AntdFormItem`组件的`label`值，优先级低于各`AntdFormItem`组件的`help`值.

    - tooltips (dict with strings as keys and values of type a list of or a singular dash component, string or number; optional):
        当`enableBatchControl=True`时，可用于统一设置内部各`AntdFormItem`组件的`tooltip`值，键为对应`AntdFormItem`组件的`label`值，优先级低于各`AntdFormItem`组件的`tooltip`值.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = ['helps{}', 'tooltips{}']
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdForm'
    LabelCol = TypedDict(
        'LabelCol',
        {
            'span': NotRequired[NumberType],
            'offset': NotRequired[NumberType],
            'flex': NotRequired[typing.Union[str, NumberType]],
        },
    )

    WrapperCol = TypedDict(
        'WrapperCol',
        {
            'span': NotRequired[NumberType],
            'offset': NotRequired[NumberType],
            'flex': NotRequired[typing.Union[str, NumberType]],
        },
    )

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        layout: typing.Optional[Literal['horizontal', 'vertical', 'inline']] = None,
        labelCol: typing.Optional['LabelCol'] = None,
        wrapperCol: typing.Optional['WrapperCol'] = None,
        colon: typing.Optional[bool] = None,
        labelAlign: typing.Optional[Literal['left', 'right']] = None,
        labelWrap: typing.Optional[bool] = None,
        enableBatchControl: typing.Optional[bool] = None,
        values: typing.Optional[dict] = None,
        validateStatuses: typing.Optional[
            typing.Dict[
                typing.Union[str, float, int], Literal['success', 'warning', 'error', 'validating']
            ]
        ] = None,
        helps: typing.Optional[typing.Dict[typing.Union[str, float, int], ComponentType]] = None,
        tooltips: typing.Optional[typing.Dict[typing.Union[str, float, int], ComponentType]] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'layout',
            'labelCol',
            'wrapperCol',
            'colon',
            'labelAlign',
            'labelWrap',
            'enableBatchControl',
            'values',
            'validateStatuses',
            'helps',
            'tooltips',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'layout',
            'labelCol',
            'wrapperCol',
            'colon',
            'labelAlign',
            'labelWrap',
            'enableBatchControl',
            'values',
            'validateStatuses',
            'helps',
            'tooltips',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdForm, self).__init__(children=children, **args)


setattr(AntdForm, '__init__', _explicitize_args(AntdForm.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdMentions(Component):
    """An AntdMentions component.
    提及组件AntdMentions

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - popupClassName (string; optional):
        展开菜单css类名.

    - name (string; optional):
        配合`AntdForm`表单批量值搜集/控制功能使用，充当当前表单项的字段名，以`id`作为缺省值.

    - enableBatchControl (boolean; default True):
        控制当前组件是否参与有效的`AntdForm`表单批量值搜集/控制功能 默认值：`True`.

    - autoSize (dict; default False):
        配置输入框高度自适应相关功能 默认值：`False`.

        `autoSize` is a boolean | dict with keys:

        - minRows (number; optional):
            输入框最小行数.

        - maxRows (number; optional):
            输入框最大行数.

    - prefix (string; default '@'):
        触发选择菜单展开的关键字 默认值：`'@'`.

    - value (string; optional):
        监听或设置已输入值.

    - defaultValue (string; optional):
        初始化已输入值.

    - options (list of dicts; required):
        必填，配置选择菜单子项.

        `options` is a list of dicts with keys:

        - label (a list of or a singular dash component, string or number; optional):
            组件型，当前选项标签内容.

        - value (string; optional):
            当前选项值.

    - selectedOptions (list of strings; optional):
        监听输入内容中对应的已选子项值.

    - disabled (boolean; default False):
        是否禁用当前组件 默认值：`False`.

    - placement (a value equal to: 'top', 'bottom'; default 'bottom'):
        选择菜单弹出方向，可选项有`'top'`、`'bottom'` 默认值：`'bottom'`.

    - bordered (boolean; default True):
        是否显示边框，设置为`True`时等价于`variant='outlined'` 默认值：`True`.

    - variant (a value equal to: 'outlined', 'borderless', 'filled', 'underlined'; optional):
        形态变体类型，可选项有`'outlined'`、`'borderless'`、`'filled'`、`'underlined'`，其中`'outlined'`等价于`bordered=True`，但优先级更高.

    - placeholder (string; optional):
        输入框占位文字内容.

    - status (a value equal to: 'error', 'warning'; optional):
        控制校验状态，可选项有`'error'`、`'warning'`.

    - autoFocus (boolean; default False):
        是否自动获取焦点 默认值：`False`.

    - popupContainer (a value equal to: 'parent', 'body'; optional):
        相关展开层锚定策略，可选项有`'parent'`、`'body'` 默认值：`'body'`.

    - batchPropsNames (list of strings; optional):
        需要纳入[批量属性监听](/batch-props-values)的若干属性名.

    - batchPropsValues (dict; optional):
        监听`batchPropsNames`中指定的若干属性值.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = ['options[].label']
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdMentions'
    AutoSize = TypedDict(
        'AutoSize', {'minRows': NotRequired[NumberType], 'maxRows': NotRequired[NumberType]}
    )

    Options = TypedDict('Options', {'label': NotRequired[ComponentType], 'value': NotRequired[str]})

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        popupClassName: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        enableBatchControl: typing.Optional[bool] = None,
        autoSize: typing.Optional[typing.Union[bool, 'AutoSize']] = None,
        prefix: typing.Optional[str] = None,
        value: typing.Optional[str] = None,
        defaultValue: typing.Optional[str] = None,
        options: typing.Optional[typing.Sequence['Options']] = None,
        selectedOptions: typing.Optional[typing.Sequence[str]] = None,
        disabled: typing.Optional[bool] = None,
        placement: typing.Optional[Literal['top', 'bottom']] = None,
        bordered: typing.Optional[bool] = None,
        variant: typing.Optional[Literal['outlined', 'borderless', 'filled', 'underlined']] = None,
        placeholder: typing.Optional[str] = None,
        status: typing.Optional[Literal['error', 'warning']] = None,
        autoFocus: typing.Optional[bool] = None,
        popupContainer: typing.Optional[Literal['parent', 'body']] = None,
        batchPropsNames: typing.Optional[typing.Sequence[str]] = None,
        batchPropsValues: typing.Optional[dict] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'popupClassName',
            'name',
            'enableBatchControl',
            'autoSize',
            'prefix',
            'value',
            'defaultValue',
            'options',
            'selectedOptions',
            'disabled',
            'placement',
            'bordered',
            'variant',
            'placeholder',
            'status',
            'autoFocus',
            'popupContainer',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'popupClassName',
            'name',
            'enableBatchControl',
            'autoSize',
            'prefix',
            'value',
            'defaultValue',
            'options',
            'selectedOptions',
            'disabled',
            'placement',
            'bordered',
            'variant',
            'placeholder',
            'status',
            'autoFocus',
            'popupContainer',
            'batchPropsNames',
            'batchPropsValues',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        for k in ['options']:
            if k not in args:
                raise TypeError('Required argument `' + k + '` was not specified.')

        super(AntdMentions, self).__init__(**args)


setattr(AntdMentions, '__init__', _explicitize_args(AntdMentions.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdDrawer(Component):
    """An AntdDrawer component.
    抽屉组件AntdDrawer

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，内嵌元素.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - classNames (dict; optional):
        配置各子元素的css类名.

        `classNames` is a dict with keys:

        - header (string; optional):
            头部元素css类名.

        - body (string; optional):
            内容元素css类名.

        - footer (string; optional):
            底部元素css类名.

        - mask (string; optional):
            遮罩层元素css类名.

        - content (string; optional):
            抽屉容器元素css类名.

    - styles (dict; optional):
        配置各子元素的css样式.

        `styles` is a dict with keys:

        - header (dict; optional):
            头部元素css样式.

        - body (dict; optional):
            内容元素css样式.

        - footer (dict; optional):
            底部元素css样式.

        - mask (dict; optional):
            遮罩层元素css样式.

        - content (dict; optional):
            抽屉容器元素css样式.

    - rootStyle (dict; optional):
        抽屉根节点css样式（包含遮罩层），特殊的，当设置了`containerId`或`containerSelector`时，该参数会自动设置`position`为`absolute`.

    - visible (boolean; default False):
        监听或设置抽屉是否可见 默认值：`False`.

    - title (a list of or a singular dash component, string or number; optional):
        组件型，抽屉标题内容.

    - placement (a value equal to: 'left', 'right', 'top', 'bottom'; default 'right'):
        抽屉弹出位置，可选项有`'left'`、`'right'`、`'top'`、`'bottom'` 默认值：`'right'`.

    - closable (boolean; default True):
        是否显示关闭按钮 默认值：`True`.

    - forceRender (boolean; default False):
        是否对抽屉内的子元素进行预渲染 默认值：`False`.

    - destroyOnClose (boolean; default False):
        是否在关闭时销毁抽屉内的子元素 默认值：`False`.

    - width (number | string; default 256):
        抽屉像素宽度，`placement`为`'left'`、`'right'`时有效 默认值：`256`.

    - height (number | string; default 256):
        抽屉像素高度，`placement`为`'top'`、`'bottom'`时有效 默认值：`256`.

    - mask (boolean; default True):
        是否显示遮罩层 默认值：`True`.

    - maskClosable (boolean; default True):
        是否允许点击遮罩区域关闭抽屉 默认值：`True`.

    - zIndex (number; default 1000):
        抽屉整体`z-index` 默认值：`1000`.

    - loading (boolean; default False):
        是否渲染为加载中状态 默认值：`False`.

    - extra (a list of or a singular dash component, string or number; optional):
        组件型，额外操作区元素.

    - footer (a list of or a singular dash component, string or number; optional):
        组件型，底部元素.

    - containerId (string; optional):
        用于设置`position`为`relative`的局部容器id.

    - containerSelector (string; optional):
        当目标容器定位较为复杂时，可传入获取元素对应的js代码字符串，优先级低于`containerId`.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = ['title', 'extra', 'footer']
    _base_nodes = ['title', 'extra', 'footer', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdDrawer'
    ClassNames = TypedDict(
        'ClassNames',
        {
            'header': NotRequired[str],
            'body': NotRequired[str],
            'footer': NotRequired[str],
            'mask': NotRequired[str],
            'content': NotRequired[str],
        },
    )

    Styles = TypedDict(
        'Styles',
        {
            'header': NotRequired[dict],
            'body': NotRequired[dict],
            'footer': NotRequired[dict],
            'mask': NotRequired[dict],
            'content': NotRequired[dict],
        },
    )

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        classNames: typing.Optional['ClassNames'] = None,
        styles: typing.Optional['Styles'] = None,
        rootStyle: typing.Optional[dict] = None,
        visible: typing.Optional[bool] = None,
        title: typing.Optional[ComponentType] = None,
        placement: typing.Optional[Literal['left', 'right', 'top', 'bottom']] = None,
        closable: typing.Optional[bool] = None,
        forceRender: typing.Optional[bool] = None,
        destroyOnClose: typing.Optional[bool] = None,
        width: typing.Optional[typing.Union[NumberType, str]] = None,
        height: typing.Optional[typing.Union[NumberType, str]] = None,
        mask: typing.Optional[bool] = None,
        maskClosable: typing.Optional[bool] = None,
        zIndex: typing.Optional[NumberType] = None,
        loading: typing.Optional[bool] = None,
        extra: typing.Optional[ComponentType] = None,
        footer: typing.Optional[ComponentType] = None,
        containerId: typing.Optional[str] = None,
        containerSelector: typing.Optional[str] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'classNames',
            'styles',
            'rootStyle',
            'visible',
            'title',
            'placement',
            'closable',
            'forceRender',
            'destroyOnClose',
            'width',
            'height',
            'mask',
            'maskClosable',
            'zIndex',
            'loading',
            'extra',
            'footer',
            'containerId',
            'containerSelector',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'classNames',
            'styles',
            'rootStyle',
            'visible',
            'title',
            'placement',
            'closable',
            'forceRender',
            'destroyOnClose',
            'width',
            'height',
            'mask',
            'maskClosable',
            'zIndex',
            'loading',
            'extra',
            'footer',
            'containerId',
            'containerSelector',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdDrawer, self).__init__(children=children, **args)


setattr(AntdDrawer, '__init__', _explicitize_args(AntdDrawer.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdCollapse(Component):
    """An AntdCollapse component.
    折叠面板组件AntdCollapse

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - children (a list of or a singular dash component, string or number; optional):
        组件型，内嵌元素.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - styles (dict; optional):
        细分控制子元素css样式.

        `styles` is a dict with keys:

        - header (dict; optional):
            头部元素css样式.

        - body (dict; optional):
            内容元素css样式.

    - classNames (dict; optional):
        细分控制子元素css类名.

        `classNames` is a dict with keys:

        - header (string; optional):
            头部元素css类名.

        - body (string; optional):
            内容元素css类名.

    - title (a list of or a singular dash component, string or number; optional):
        组件型，标题内容.

    - isOpen (boolean; default True):
        是否展开 默认值：`True`.

    - size (a value equal to: 'large', 'middle', 'small'; default 'middle'):
        组件尺寸规格，可选项有`'small'`、`'middle'`、`'large'` 默认值：`'middle'`.

    - bordered (boolean; default True):
        是否渲染边框 默认值：`True`.

    - showArrow (boolean; default True):
        是否渲染箭头 默认值：`True`.

    - ghost (boolean; default False):
        是否开启透明背景模式 默认值：`False`.

    - collapsible (a value equal to: 'header', 'disabled', 'icon'; optional):
        折叠交互触发行为，可选项有`'header'`（仅标题区域）、`'disabled'`（禁用折叠）、`'icon'`（仅图标区域）.

    - forceRender (boolean; default False):
        初始化未展开时，是否强制渲染内部元素 默认值：`False`.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配.

    - persistence (boolean | string | number; optional):
        是否开启[属性持久化](/prop-persistence).

    - persisted_props (list of a value equal to: 'isOpen's; optional):
        开启属性持久化功能的若干属性名，可选项有`'isOpen'` 默认值：`['isOpen']`.

    - persistence_type (a value equal to: 'local', 'session', 'memory'; optional):
        属性持久化存储类型，可选项有`'local'`（本地持久化），`'session'`（会话持久化），`'memory'`（内存持久化）
        默认值：`'local'`."""

    _children_props: typing.List[str] = ['title']
    _base_nodes = ['title', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdCollapse'
    Styles = TypedDict('Styles', {'header': NotRequired[dict], 'body': NotRequired[dict]})

    ClassNames = TypedDict('ClassNames', {'header': NotRequired[str], 'body': NotRequired[str]})

    def __init__(
        self,
        children: typing.Optional[ComponentType] = None,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        styles: typing.Optional['Styles'] = None,
        classNames: typing.Optional['ClassNames'] = None,
        title: typing.Optional[ComponentType] = None,
        isOpen: typing.Optional[bool] = None,
        size: typing.Optional[Literal['large', 'middle', 'small']] = None,
        bordered: typing.Optional[bool] = None,
        showArrow: typing.Optional[bool] = None,
        ghost: typing.Optional[bool] = None,
        collapsible: typing.Optional[Literal['header', 'disabled', 'icon']] = None,
        forceRender: typing.Optional[bool] = None,
        persistence: typing.Optional[typing.Union[bool, str, NumberType]] = None,
        persisted_props: typing.Optional[typing.Sequence[Literal['isOpen']]] = None,
        persistence_type: typing.Optional[Literal['local', 'session', 'memory']] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'styles',
            'classNames',
            'title',
            'isOpen',
            'size',
            'bordered',
            'showArrow',
            'ghost',
            'collapsible',
            'forceRender',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'children',
            'style',
            'className',
            'styles',
            'classNames',
            'title',
            'isOpen',
            'size',
            'bordered',
            'showArrow',
            'ghost',
            'collapsible',
            'forceRender',
            'data-*',
            'aria-*',
            'persistence',
            'persisted_props',
            'persistence_type',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args if k != 'children'}

        super(AntdCollapse, self).__init__(children=children, **args)


setattr(AntdCollapse, '__init__', _explicitize_args(AntdCollapse.__init__))



import time

from dash import Dash, html
from feffery_dash_utils.style_utils import style
from selenium.webdriver.common.by import By

import feffery_antd_components as fac


def test_locale_french(dash_duo):
    app = Dash(__name__)
    app.layout = html.Div(
        fac.AntdSpace(
            [
                fac.AntdEmpty(locale='fr-fr'),
                fac.AntdConfigProvider(fac.AntdEmpty(), locale='fr-fr'),
            ],
            direction='vertical',
            style=style(width='100%'),
        ),
        style=style(padding=50),
    )

    dash_duo.start_server(app)

    time.sleep(1)

    descriptions = dash_duo.driver.find_elements(
        By.XPATH, '//div[contains(@class, "ant-empty-description")]'
    )
    assert len(descriptions) == 2
    for desc in descriptions:
        assert desc.text == 'Aucune donnée'



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdResult(Component):
    """An AntdResult component.
    结果组件AntdResult

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - extra (a list of or a singular dash component, string or number; optional):
        组件型，操作区域.

    - status (a value equal to: 'success', 'error', 'info', 'warning', '404', '403', '500', 'loading'; default 'info'):
        状态，可选项有`'success'`、`'error'`、`'info'`、`'warning'`、`'404'`、`'403'`、`'500'`
        默认值：`'info'`.

    - title (a list of or a singular dash component, string or number; optional):
        组件型，标题内容.

    - subTitle (a list of or a singular dash component, string or number; optional):
        组件型，副标题内容.

    - icon (a list of or a singular dash component, string or number; optional):
        组件型，图标内容.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = ['extra', 'title', 'subTitle', 'icon']
    _base_nodes = ['extra', 'title', 'subTitle', 'icon', 'children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdResult'

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        extra: typing.Optional[ComponentType] = None,
        status: typing.Optional[
            Literal['success', 'error', 'info', 'warning', '404', '403', '500', 'loading']
        ] = None,
        title: typing.Optional[ComponentType] = None,
        subTitle: typing.Optional[ComponentType] = None,
        icon: typing.Optional[ComponentType] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'extra',
            'status',
            'title',
            'subTitle',
            'icon',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'extra',
            'status',
            'title',
            'subTitle',
            'icon',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdResult, self).__init__(**args)


setattr(AntdResult, '__init__', _explicitize_args(AntdResult.__init__))



# AUTO GENERATED FILE - DO NOT EDIT

import typing  # noqa: F401

from dash.development.base_component import Component, _explicitize_args
from typing_extensions import Literal, NotRequired, TypedDict  # noqa: F401

ComponentSingleType = typing.Union[str, int, float, Component, None]
ComponentType = typing.Union[
    ComponentSingleType,
    typing.Sequence[ComponentSingleType],
]

NumberType = typing.Union[typing.SupportsFloat, typing.SupportsInt, typing.SupportsComplex]


class AntdColorPicker(Component):
    """An AntdColorPicker component.
    颜色选择器组件AntdColorPicker

    Keyword arguments:

    - id (string; optional):
        组件唯一id.

    - key (string; optional):
        对当前组件的`key`值进行更新，可实现强制重绘当前组件的效果.

    - className (string | dict; optional):
        当前组件css类名，支持[动态css](/advanced-classname).

    - locale (a value equal to: 'zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr'; default 'zh-cn'):
        组件文案语种，可选项有`'zh-cn'`（简体中文）、`'en-us'`（英语）、`'de-de'`（德语）、`'fr-fr'`（法语）、`'ru-ru'`（俄语）
        默认值：`'zh-cn'`.

    - name (string; optional):
        配合`AntdForm`表单批量值搜集/控制功能使用，充当当前表单项的字段名，以`id`作为缺省值.

    - enableBatchControl (boolean; default True):
        控制当前组件是否参与有效的`AntdForm`表单批量值搜集/控制功能 默认值：`True`.

    - allowClear (boolean; default False):
        是否允许清除已选颜色 默认值：`False`.

    - arrow (dict; optional):
        配置颜色选择面板额外箭头 默认值：`True`.

        `arrow` is a boolean | dict with keys:

        - pointAtCenter (boolean; optional):
            箭头是否指向面板中心 默认值：`False`.

    - defaultValue (string; optional):
        初始化已输入值.

    - value (string; optional):
        监听或设置选中颜色值 默认值：`'#1677FF'`.

    - format (a value equal to: 'rgb', 'hex', 'hsb'; default 'hex'):
        监听或设置颜色格式，可选项有`'rgb'`、`'hex'`、`'hsb'` 默认值：`'hex'`.

    - mode (a value equal to: 'single', 'gradient' | list of a value equal to: 'single', 'gradient's; default 'single'):
        选择器模式，用于配置单色与渐变，可选项有`'single'`、`'gradient'`，支持单选项或多选项组合
        默认值：`single`.

    - disabled (boolean; default False):
        是否禁用当前组件 默认值：`False`.

    - disabledAlpha (boolean; default True):
        是否禁用透明度选择 默认值：`True`.

    - open (boolean; optional):
        监听或设置颜色选择面板展开状态.

    - presets (list of dicts; optional):
        配置预设颜色选择项.

        `presets` is a list of dicts with keys:

        - label (a list of or a singular dash component, string or number; optional):
            组件型，当前预设项标签内容.

        - colors (list of strings; optional):
            当前预设项所包含的颜色值数组.

        - defaultOpen (boolean; optional):
            当前预设项默认是否展开 默认值：`True`.

    - placement (a value equal to: 'top', 'topLeft', 'topRight', 'bottom', 'bottomLeft', 'bottomRight'; default 'bottomLeft'):
        颜色选择面板展开方向，可选项有`'top'`、`'topLeft'`、`'topRight'`、`'bottom'`、`'bottomLeft'`、`'bottomRight'`
        默认值：`'bottomRight'`.

    - showText (boolean; default False):
        是否显示颜色值文本 默认值：`False`.

    - size (a value equal to: 'large', 'middle', 'small'; default 'middle'):
        设置触发控件尺寸规格，可选项有`'large'`、`'middle'`、`'small'` 默认值：`'middle'`.

    - trigger (a value equal to: 'hover', 'click'; default 'click'):
        颜色选择面板触发方式，可选项有`'hover'`、`'click'` 默认值：`'click'`.

    - data-* (string; optional):
        `data-*`格式属性通配.

    - aria-* (string; optional):
        `aria-*`格式属性通配."""

    _children_props: typing.List[str] = ['presets[].label']
    _base_nodes = ['children']
    _namespace = 'feffery_antd_components'
    _type = 'AntdColorPicker'
    Arrow = TypedDict('Arrow', {'pointAtCenter': NotRequired[bool]})

    Presets = TypedDict(
        'Presets',
        {
            'label': NotRequired[ComponentType],
            'colors': NotRequired[typing.Sequence[str]],
            'defaultOpen': NotRequired[bool],
        },
    )

    def __init__(
        self,
        id: typing.Optional[typing.Union[str, dict]] = None,
        key: typing.Optional[str] = None,
        style: typing.Optional[typing.Any] = None,
        className: typing.Optional[typing.Union[str, dict]] = None,
        locale: typing.Optional[Literal['zh-cn', 'en-us', 'de-de', 'ru-ru', 'fr-fr']] = None,
        name: typing.Optional[str] = None,
        enableBatchControl: typing.Optional[bool] = None,
        allowClear: typing.Optional[bool] = None,
        arrow: typing.Optional[typing.Union[bool, 'Arrow']] = None,
        defaultValue: typing.Optional[str] = None,
        value: typing.Optional[str] = None,
        format: typing.Optional[Literal['rgb', 'hex', 'hsb']] = None,
        mode: typing.Optional[
            typing.Union[
                Literal['single', 'gradient'], typing.Sequence[Literal['single', 'gradient']]
            ]
        ] = None,
        disabled: typing.Optional[bool] = None,
        disabledAlpha: typing.Optional[bool] = None,
        open: typing.Optional[bool] = None,
        presets: typing.Optional[typing.Sequence['Presets']] = None,
        placement: typing.Optional[
            Literal['top', 'topLeft', 'topRight', 'bottom', 'bottomLeft', 'bottomRight']
        ] = None,
        showText: typing.Optional[bool] = None,
        size: typing.Optional[Literal['large', 'middle', 'small']] = None,
        trigger: typing.Optional[Literal['hover', 'click']] = None,
        **kwargs,
    ):
        self._prop_names = [
            'id',
            'key',
            'style',
            'className',
            'locale',
            'name',
            'enableBatchControl',
            'allowClear',
            'arrow',
            'defaultValue',
            'value',
            'format',
            'mode',
            'disabled',
            'disabledAlpha',
            'open',
            'presets',
            'placement',
            'showText',
            'size',
            'trigger',
            'data-*',
            'aria-*',
        ]
        self._valid_wildcard_attributes = ['data-', 'aria-']
        self.available_properties = [
            'id',
            'key',
            'style',
            'className',
            'locale',
            'name',
            'enableBatchControl',
            'allowClear',
            'arrow',
            'defaultValue',
            'value',
            'format',
            'mode',
            'disabled',
            'disabledAlpha',
            'open',
            'presets',
            'placement',
            'showText',
            'size',
            'trigger',
            'data-*',
            'aria-*',
        ]
        self.available_wildcard_properties = ['data-', 'aria-']
        _explicit_args = kwargs.pop('_explicit_args')
        _locals = locals()
        _locals.update(kwargs)  # For wildcard attrs and excess named props
        args = {k: _locals[k] for k in _explicit_args}

        super(AntdColorPicker, self).__init__(**args)


setattr(AntdColorPicker, '__init__', _explicitize_args(AntdColorPicker.__init__))
